"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtSql import *


class QSqlRecord(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsqlrecord.html

    **Detailed Description**

    The QSqlRecord class encapsulates the functionality and characteristics of a
    database record (usually a row in a table or view within the database).
    QSqlRecord supports adding and removing fields as well as setting and
    retrieving field values.

    The values of a record's fields can be set by name or position with
    **setValue** (); if you want to set a field to null use **setNull** (). To
    find the position of a field by name use **indexOf** (), and to find the
    name of a field at a particular position use **fieldName** (). Use **field**
    () to retrieve a **QSqlField**  object for a given field. Use **contains**
    () to see if the record contains a particular field name.

    When queries are generated to be executed on the database only those fields
    for which **isGenerated** () is true are included in the generated SQL.

    A record can have fields added with **append** () or **insert** (), replaced
    with **replace** (), and removed with **remove** (). All the fields can be
    removed with **clear** (). The number of fields is given by **count** ();
    all their values can be cleared (to null) using **clearValues** ().

    **See also** **QSqlField**  and **QSqlQuery::record** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#QSqlRecord

        **QSqlRecord::QSqlRecord()**

        Constructs an empty record.

        **See also** **isEmpty** (), **append** (), and **insert** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QSqlRecord") -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#QSqlRecord-1

        **QSqlRecord::QSqlRecord(const QSqlRecord & other )**

        Constructs a copy of **other**.

        QSqlRecord is **implicitly shared** . This means you can make copies of
        a record in **constant time** .
        """
        ...

    def keyValues(self, keyFields: "QSqlRecord") -> "QSqlRecord":
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#keyValues

        **[since 5.1] QSqlRecord QSqlRecord::keyValues(const QSqlRecord &
        keyFields ) const**

        Returns a record containing the fields represented in **keyFields** set
        to values that match by field name.

        This function was introduced in Qt 5.1.
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#count

        **int QSqlRecord::count() const**

        Returns the number of fields in the record.

        **See also** **isEmpty** ().
        """
        ...

    def clearValues(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#clearValues

        **void QSqlRecord::clearValues()**

        Clears the value of all fields in the record and sets each field to
        null.

        **See also** **setValue** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#clear

        **void QSqlRecord::clear()**

        Removes all the record's fields.

        **See also** **clearValues** () and **isEmpty** ().
        """
        ...

    def contains(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#contains

        **bool QSqlRecord::contains(const QString & name ) const**

        Returns `true` if there is a field in the record called **name** ;
        otherwise returns `false`.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#isEmpty

        **bool QSqlRecord::isEmpty() const**

        Returns `true` if there are no fields in the record; otherwise returns
        `false`.

        **See also** **append** (), **insert** (), and **clear** ().
        """
        ...

    def remove(self, pos: int) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#remove

        **void QSqlRecord::remove(int pos )**

        Removes the field at position **pos**. If **pos** is out of range,
        nothing happens.

        **See also** **append** (), **insert** (), and **replace** ().
        """
        ...

    def insert(self, pos: int, field: QSqlField) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#insert

        **void QSqlRecord::insert(int pos , const QSqlField & field )**

        Inserts the field **field** at position **pos** in the record.

        **See also** **append** (), **replace** (), and **remove** ().
        """
        ...

    def replace(self, pos: int, field: QSqlField) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#replace

        **void QSqlRecord::replace(int pos , const QSqlField & field )**

        Replaces the field at position **pos** with the given **field**. If
        **pos** is out of range, nothing happens.

        **See also** **append** (), **insert** (), and **remove** ().
        """
        ...

    def append(self, field: QSqlField) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#append

        **void QSqlRecord::append(const QSqlField & field )**

        Append a copy of field **field** to the end of the record.

        **See also** **insert** (), **replace** (), and **remove** ().
        """
        ...

    @typing.overload
    def setGenerated(self, name: str, generated: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#setGenerated

        **void QSqlRecord::setGenerated(const QString & name , bool generated
        )**

        Sets the generated flag for the field called **name** to **generated**.
        If the field does not exist, nothing happens. Only fields that have
        **generated** set to true are included in the SQL that is generated by
        **QSqlQueryModel**  for example.

        **See also** **isGenerated** ().
        """
        ...

    @typing.overload
    def setGenerated(self, i: int, generated: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#setGenerated-1

        **void QSqlRecord::setGenerated(int index , bool generated )**

        This is an overloaded function.

        Sets the generated flag for the field **index** to **generated**.

        **See also** **isGenerated** ().
        """
        ...

    @typing.overload
    def isGenerated(self, i: int) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#isGenerated

        **bool QSqlRecord::isGenerated(const QString & name ) const**

        Returns `true` if the record has a field called **name** and this field
        is to be generated (the default); otherwise returns `false`.

        **See also** **setGenerated** ().
        """
        ...

    @typing.overload
    def isGenerated(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#isGenerated-1

        **bool QSqlRecord::isGenerated(int index ) const**

        This is an overloaded function.

        Returns `true` if the record has a field at position **index** and this
        field is to be generated (the default); otherwise returns `false`.

        **See also** **setGenerated** ().
        """
        ...

    @typing.overload
    def field(self, i: int) -> QSqlField:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#field

        **QSqlField QSqlRecord::field(int index ) const**

        Returns the field at position **index**. If the **index** is out of
        range, function returns a **default-constructed value** .
        """
        ...

    @typing.overload
    def field(self, name: str) -> QSqlField:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#field-1

        **QSqlField QSqlRecord::field(const QString & name ) const**

        This is an overloaded function.

        Returns the field called **name**.
        """
        ...

    def fieldName(self, i: int) -> str:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#fieldName

        **QString QSqlRecord::fieldName(int index ) const**

        Returns the name of the field at position **index**. If the field does
        not exist, an empty string is returned.

        **See also** **indexOf** ().
        """
        ...

    def indexOf(self, name: str) -> int:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#indexOf

        **int QSqlRecord::indexOf(const QString & name ) const**

        Returns the position of the field called **name** within the record, or
        -1 if it cannot be found. Field names are not case-sensitive. If more
        than one field matches, the first one is returned.

        **See also** **fieldName** ().
        """
        ...

    @typing.overload
    def isNull(self, i: int) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#isNull

        **bool QSqlRecord::isNull(const QString & name ) const**

        Returns `true` if the field called **name** is null or if there is no
        field called **name** ; otherwise returns `false`.

        **See also** **setNull** ().
        """
        ...

    @typing.overload
    def isNull(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#isNull-1

        **bool QSqlRecord::isNull(int index ) const**

        This is an overloaded function.

        Returns `true` if the field **index** is null or if there is no field at
        position **index** ; otherwise returns `false`.
        """
        ...

    @typing.overload
    def setNull(self, i: int) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#setNull

        **void QSqlRecord::setNull(int index )**

        Sets the value of field **index** to null. If the field does not exist,
        nothing happens.

        **See also** **isNull** () and **setValue** ().
        """
        ...

    @typing.overload
    def setNull(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#setNull-1

        **void QSqlRecord::setNull(const QString & name )**

        This is an overloaded function.

        Sets the value of the field called **name** to null. If the field does
        not exist, nothing happens.
        """
        ...

    @typing.overload
    def setValue(self, i: int, val: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#setValue

        **void QSqlRecord::setValue(int index , const QVariant & val )**

        Sets the value of the field at position **index** to **val**. If the
        field does not exist, nothing happens.

        **See also** **value** () and **setNull** ().
        """
        ...

    @typing.overload
    def setValue(self, name: str, val: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#setValue-1

        **void QSqlRecord::setValue(const QString & name , const QVariant & val
        )**

        This is an overloaded function.

        Sets the value of the field called **name** to **val**. If the field
        does not exist, nothing happens.
        """
        ...

    @typing.overload
    def value(self, i: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#value

        **QVariant QSqlRecord::value(int index ) const**

        Returns the value of the field located at position **index** in the
        record. If **index** is out of bounds, an invalid **QVariant**  is
        returned.

        **See also** **setValue** (), **fieldName** (), and **isNull** ().
        """
        ...

    @typing.overload
    def value(self, name: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlrecord.html#value-1

        **QVariant QSqlRecord::value(const QString & name ) const**

        This is an overloaded function.

        Returns the value of the field called **name** in the record. If field
        **name** does not exist an invalid variant is returned.

        **See also** **indexOf** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QModelRoleData(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmodelroledata.html

    **Detailed Description**

    QModelRoleData objects store an item role (which is a value from the
    **Qt::ItemDataRole**  enumeration, or an arbitrary integer for a custom
    role) as well as the data associated with that role.

    A QModelRoleData object is typically created by views or delegates, setting
    which role they want to fetch the data for. The object is then passed to
    models (see **QAbstractItemModel::multiData** ()), which populate the data
    corresponding to the role stored. Finally, the view visualizes the data
    retrieved from the model.

    **See also** **Model/View Programming**  and **QModelRoleDataSpan** .
    """

    @typing.overload
    def __init__(self, role: int) -> None:
        """
        https://doc.qt.io/qt-6/qmodelroledata.html#QModelRoleData

        **QModelRoleData::QModelRoleData(int role )**

        Constructs a QModelRoleData object for the given **role**.

        **See also** **Qt::ItemDataRole** .
        """
        ...

    @typing.overload
    def __init__(self, a0: "QModelRoleData") -> None:
        """
        https://doc.qt.io/qt-6/qmodelroledata.html#QModelRoleData

        **QModelRoleData::QModelRoleData(int role )**

        Constructs a QModelRoleData object for the given **role**.

        **See also** **Qt::ItemDataRole** .
        """
        ...

    def clearData(self) -> None:
        """
        https://doc.qt.io/qt-6/qmodelroledata.html#clearData

        **void QModelRoleData::clearData()**

        Clears the data held by this object. Note that the role is unchanged;
        only the data is cleared.

        **See also** **data** ().
        """
        ...

    def setData(self, data: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qmodelroledata.html#setData

        **template <typename T> void QModelRoleData::setData(T && value )**

        Sets the data held by this object to **value**. **value** must be of a
        datatype which can be stored in a **QVariant** .

        **See also** **data** (), **clearData** (), and **Q_DECLARE_METATYPE** .
        """
        ...

    def data(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmodelroledata.html#data

        **QVariant &QModelRoleData::data()**

        Returns the data held by this object as a modifiable reference.

        **See also** **setData** ().
        """
        ...

    def role(self) -> int:
        """
        https://doc.qt.io/qt-6/qmodelroledata.html#role

        **int QModelRoleData::role() const**

        Returns the role held by this object.

        **See also** **Qt::ItemDataRole** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QSpacerItem(QLayoutItem):
    """
    https://doc.qt.io/qt-6/qspaceritem.html

    **Detailed Description**

    Normally, you don't need to use this class directly. Qt's built-in layout
    managers provide the following functions for manipulating empty space in
    layouts:

    ClassFunctions
    **QHBoxLayout** **addSpacing** (), **addStretch** (),
    **insertSpacing** (), **insertStretch** ()
    **QGridLayout**
    **setRowMinimumHeight** (), **setRowStretch** (), **setColumnMinimumWidth**
    (), **setColumnStretch** ()

    **See also** **QLayout** , **QWidgetItem** , and **QLayoutItem::spacerItem**
    ().
    """

    @typing.overload
    def __init__(
        self,
        w: int,
        h: int,
        hPolicy: "QSizePolicy.Policy" = ...,
        vPolicy: "QSizePolicy.Policy" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qspaceritem.html#QSpacerItem

        **QSpacerItem::QSpacerItem(int w , int h , QSizePolicy::Policy hPolicy =
        QSizePolicy::Minimum, QSizePolicy::Policy vPolicy =
        QSizePolicy::Minimum)**

        Constructs a spacer item with preferred width **w** , preferred height
        **h** , horizontal size policy **hPolicy** and vertical size policy
        **vPolicy**.

        The default values provide a gap that is able to stretch if nothing else
        wants the space.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QSpacerItem") -> None:
        """
        https://doc.qt.io/qt-6/qspaceritem.html#QSpacerItem

        **QSpacerItem::QSpacerItem(int w , int h , QSizePolicy::Policy hPolicy =
        QSizePolicy::Minimum, QSizePolicy::Policy vPolicy =
        QSizePolicy::Minimum)**

        Constructs a spacer item with preferred width **w** , preferred height
        **h** , horizontal size policy **hPolicy** and vertical size policy
        **vPolicy**.

        The default values provide a gap that is able to stretch if nothing else
        wants the space.
        """
        ...

    def sizePolicy(self) -> "QSizePolicy":
        """
        https://doc.qt.io/qt-6/qspaceritem.html#sizePolicy

        **[since 5.5] QSizePolicy QSpacerItem::sizePolicy() const**

        Returns the size policy of this item.

        This function was introduced in Qt 5.5.
        """
        ...

    def spacerItem(self) -> "QSpacerItem":
        """
        https://doc.qt.io/qt-6/qspaceritem.html#spacerItem

        **[override virtual] QSpacerItem *QSpacerItem::spacerItem()**

        Reimplements: **QLayoutItem::spacerItem** ().

        Returns a pointer to this object.
        """
        ...

    def geometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qspaceritem.html#geometry

        **[override virtual] QRect QSpacerItem::geometry() const**

        Reimplements: **QLayoutItem::geometry() const** .

        **See also** **setGeometry** ().
        """
        ...

    def setGeometry(self, a0: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qspaceritem.html#setGeometry

        **[override virtual] void QSpacerItem::setGeometry(const QRect & r )**

        Reimplements: **QLayoutItem::setGeometry** (const QRect &r).

        **See also** **geometry** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qspaceritem.html#isEmpty

        **[override virtual] bool QSpacerItem::isEmpty() const**

        Reimplements: **QLayoutItem::isEmpty() const** .

        Returns `true`.
        """
        ...

    def expandingDirections(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qspaceritem.html#expandingDirections

        **[override virtual] Qt::Orientations QSpacerItem::expandingDirections()
        const**

        Reimplements: **QLayoutItem::expandingDirections() const** .
        """
        ...

    def maximumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qspaceritem.html#maximumSize

        **[override virtual] QSize QSpacerItem::maximumSize() const**

        Reimplements: **QLayoutItem::maximumSize() const** .
        """
        ...

    def minimumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qspaceritem.html#minimumSize

        **[override virtual] QSize QSpacerItem::minimumSize() const**

        Reimplements: **QLayoutItem::minimumSize() const** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qspaceritem.html#sizeHint

        **[override virtual] QSize QSpacerItem::sizeHint() const**

        Reimplements: **QLayoutItem::sizeHint() const** .
        """
        ...

    def changeSize(
        self,
        w: int,
        h: int,
        hPolicy: "QSizePolicy.Policy" = ...,
        vPolicy: "QSizePolicy.Policy" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qspaceritem.html#changeSize

        **void QSpacerItem::changeSize(int w , int h , QSizePolicy::Policy
        hPolicy = QSizePolicy::Minimum, QSizePolicy::Policy vPolicy =
        QSizePolicy::Minimum)**

        Changes this spacer item to have preferred width **w** , preferred
        height **h** , horizontal size policy **hPolicy** and vertical size
        policy **vPolicy**.

        The default values provide a gap that is able to stretch if nothing else
        wants the space.

        Note that if changeSize() is called after the spacer item has been added
        to a layout, it is necessary to invalidate the layout in order for the
        spacer item's new size to take effect.

        **See also** **QSpacerItem::invalidate** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QTextBrowser(QTextEdit):
    """
    https://doc.qt.io/qt-6/qtextbrowser.html

    **Detailed Description**

    This class extends **QTextEdit**  (in read-only mode), adding some
    navigation functionality so that users can follow links in hypertext
    documents.

    If you want to provide your users with an editable rich text editor, use
    **QTextEdit** . If you want a text browser without hypertext navigation use
    **QTextEdit** , and use **QTextEdit::setReadOnly** () to disable editing. If
    you just need to display a small piece of rich text use **QLabel** .

    **Document Source and Contents**

    The contents of **QTextEdit**  are set with **setHtml** () or
    **setPlainText** (), but QTextBrowser also implements the **setSource** ()
    function, making it possible to use a named document as the source text. The
    name is looked up in a list of search paths and in the directory of the
    current document factory.

    If a document name ends with an anchor (for example, "`#anchor"`), the text
    browser automatically scrolls to that position (using **scrollToAnchor**
    ()). When the user clicks on a hyperlink, the browser will call
    **setSource** () itself with the link's `href` value as argument. You can
    track the current source by connecting to the **sourceChanged** () signal.

    **Navigation**

    QTextBrowser provides **backward** () and **forward** () slots which you can
    use to implement Back and Forward buttons. The **home** () slot sets the
    text to the very first document displayed. The **anchorClicked** () signal
    is emitted when the user clicks an anchor. To override the default
    navigation behavior of the browser, call the **setSource** () function to
    supply new document text in a slot connected to this signal.

    If you want to load documents stored in the Qt resource system use `qrc` as
    the scheme in the URL to load. For example, for the document resource path
    `:/docs/index.html` use `qrc:/docs/index.html` as the URL with **setSource**
    ().

    **See also** **QTextEdit**  and **QTextDocument** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#QTextBrowser

        **QTextBrowser::QTextBrowser(QWidget * parent = nullptr)**

        Constructs an empty QTextBrowser with parent **parent**.
        """
        ...

    def doSetSource(
        self, name: QtCore.QUrl, type: QtGui.QTextDocument.ResourceType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#doSetSource

        **[virtual protected] void QTextBrowser::doSetSource(const QUrl & url ,
        QTextDocument::ResourceType type = QTextDocument::UnknownResource)**

        Attempts to load the document at the given **url** with the specified
        **type**.

        **setSource** () calls doSetSource. In Qt 5, **setSource** (const
        **QUrl**  &url) was virtual. In Qt 6, doSetSource() is virtual instead,
        so that it can be overridden in subclasses.
        """
        ...

    def sourceType(self) -> QtGui.QTextDocument.ResourceType:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#sourceType-prop

        **[read-only] sourceType : const QTextDocument::ResourceType**

        This property holds the type of the displayed document

        This is **QTextDocument::UnknownResource**  if no document is displayed
        or if the type of the source is unknown. Otherwise it holds the type
        that was detected, or the type that was specified when **setSource** ()
        was called.

        **Access functions:**

        QTextDocument::ResourceType **sourceType** () const
        """
        ...

    def forwardHistoryCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#forwardHistoryCount

        **int QTextBrowser::forwardHistoryCount() const**

        Returns the number of locations forward in the history.
        """
        ...

    def backwardHistoryCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#backwardHistoryCount

        **int QTextBrowser::backwardHistoryCount() const**

        Returns the number of locations backward in the history.
        """
        ...

    def historyUrl(self, a0: int) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#historyUrl

        **QUrl QTextBrowser::historyUrl(int i ) const**

        Returns the url of the HistoryItem.

        InputReturn
        **i** < 0**backward** () history
        **i** == 0current, see
        **QTextBrowser::source** ()
        **i** > 0**forward** () history
        """
        ...

    def historyTitle(self, a0: int) -> str:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#historyTitle

        **QString QTextBrowser::historyTitle(int i ) const**

        Returns the **documentTitle** () of the HistoryItem.

        InputReturn
        **i** < 0**backward** () history
        **i** == 0current, see
        **QTextBrowser::source** ()
        **i** > 0**forward** () history

        backaction.setToolTip(browser.historyTitle(-1));
        forwardaction.setToolTip(browser.historyTitle(+1));
        """
        ...

    def setOpenLinks(self, open: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#openLinks-prop

        **openLinks : bool**

        This property specifies whether **QTextBrowser**  should automatically
        open links the user tries to activate by mouse or keyboard.

        Regardless of the value of this property the **anchorClicked**  signal
        is always emitted.

        The default value is true.

        **Access functions:**

        bool **openLinks** () const
        void **setOpenLinks** (bool **open** )
        """
        ...

    def openLinks(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#openLinks-prop

        **openLinks : bool**

        This property specifies whether **QTextBrowser**  should automatically
        open links the user tries to activate by mouse or keyboard.

        Regardless of the value of this property the **anchorClicked**  signal
        is always emitted.

        The default value is true.

        **Access functions:**

        bool **openLinks** () const
        void **setOpenLinks** (bool **open** )
        """
        ...

    def setOpenExternalLinks(self, open: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#openExternalLinks-prop

        **openExternalLinks : bool**

        Specifies whether **QTextBrowser**  should automatically open links to
        external sources using **QDesktopServices::openUrl** () instead of
        emitting the **anchorClicked**  signal. Links are considered external if
        their scheme is neither file or qrc.

        The default value is false.

        **Access functions:**

        bool **openExternalLinks** () const
        void **setOpenExternalLinks**
        (bool **open** )
        """
        ...

    def openExternalLinks(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#openExternalLinks-prop

        **openExternalLinks : bool**

        Specifies whether **QTextBrowser**  should automatically open links to
        external sources using **QDesktopServices::openUrl** () instead of
        emitting the **anchorClicked**  signal. Links are considered external if
        their scheme is neither file or qrc.

        The default value is false.

        **Access functions:**

        bool **openExternalLinks** () const
        void **setOpenExternalLinks**
        (bool **open** )
        """
        ...

    def clearHistory(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#clearHistory

        **void QTextBrowser::clearHistory()**

        Clears the history of visited documents and disables the forward and
        backward navigation.

        **See also** **backward** () and **forward** ().
        """
        ...

    def isForwardAvailable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#isForwardAvailable

        **bool QTextBrowser::isForwardAvailable() const**

        Returns `true` if the text browser can go forward in the document
        history using **forward** ().

        **See also** **forwardAvailable** () and **forward** ().
        """
        ...

    def isBackwardAvailable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#isBackwardAvailable

        **bool QTextBrowser::isBackwardAvailable() const**

        Returns `true` if the text browser can go backward in the document
        history using **backward** ().

        **See also** **backwardAvailable** () and **backward** ().
        """
        ...

    def paintEvent(self, e: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#paintEvent

        **[override virtual protected] void QTextBrowser::paintEvent(QPaintEvent
        * e )**

        Reimplements: **QTextEdit::paintEvent** (QPaintEvent *event).
        """
        ...

    def focusNextPrevChild(self, next: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#focusNextPrevChild

        **[override virtual protected] bool
        QTextBrowser::focusNextPrevChild(bool next )**

        Reimplements: **QTextEdit::focusNextPrevChild** (bool next).
        """
        ...

    def focusOutEvent(self, ev: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#focusOutEvent

        **[override virtual protected] void
        QTextBrowser::focusOutEvent(QFocusEvent * ev )**

        Reimplements: **QTextEdit::focusOutEvent** (QFocusEvent *e).
        """
        ...

    def mouseReleaseEvent(self, ev: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#mouseReleaseEvent

        **[override virtual protected] void
        QTextBrowser::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QTextEdit::mouseReleaseEvent** (QMouseEvent *e).
        """
        ...

    def mousePressEvent(self, ev: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#mousePressEvent

        **[override virtual protected] void
        QTextBrowser::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QTextEdit::mousePressEvent** (QMouseEvent *e).
        """
        ...

    def mouseMoveEvent(self, ev: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#mouseMoveEvent

        **[override virtual protected] void
        QTextBrowser::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QTextEdit::mouseMoveEvent** (QMouseEvent *e).
        """
        ...

    def keyPressEvent(self, ev: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#keyPressEvent

        **[override virtual protected] void
        QTextBrowser::keyPressEvent(QKeyEvent * ev )**

        Reimplements: **QTextEdit::keyPressEvent** (QKeyEvent *e).

        The event **ev** is used to provide the following keyboard shortcuts:

        KeypressAction
        Alt+Left Arrow**backward** ()
        Alt+Right
        Arrow**forward** ()
        Alt+Up Arrow**home** ()
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#event

        **[override virtual protected] bool QTextBrowser::event(QEvent * e )**

        Reimplements: **QAbstractScrollArea::event** (QEvent *event).
        """
        ...

    def reload(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#reload

        **[virtual slot] void QTextBrowser::reload()**

        Reloads the current set source.
        """
        ...

    def home(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#home

        **[virtual slot] void QTextBrowser::home()**

        Changes the document displayed to be the first document from the
        history.
        """
        ...

    def forward(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#forward

        **[virtual slot] void QTextBrowser::forward()**

        Changes the document displayed to the next document in the list of
        documents built by navigating links. Does nothing if there is no next
        document.

        **See also** **backward** () and **forwardAvailable** ().
        """
        ...

    def backward(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#backward

        **[virtual slot] void QTextBrowser::backward()**

        Changes the document displayed to the previous document in the list of
        documents built by navigating links. Does nothing if there is no
        previous document.

        **See also** **forward** () and **backwardAvailable** ().
        """
        ...

    def setSource(
        self, name: QtCore.QUrl, type: QtGui.QTextDocument.ResourceType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#setSource

        **[slot] void QTextBrowser::setSource(const QUrl & url ,
        QTextDocument::ResourceType type = QTextDocument::UnknownResource)**

        Attempts to load the document at the given **url** with the specified
        **type**.

        If **type** is **UnknownResource**  (the default), the document type
        will be detected: that is, if the url ends with an extension of `.md`,
        `.mkd` or `.markdown`, the document will be loaded via
        **QTextDocument::setMarkdown** (); otherwise it will be loaded via
        **QTextDocument::setHtml** (). This detection can be bypassed by
        specifying the **type** explicitly.

        **Note:** Setter function for property **source** .

        **See also** **source** ().
        """
        ...

    def loadResource(self, type: int, name: QtCore.QUrl) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#loadResource

        **[override virtual] QVariant QTextBrowser::loadResource(int type ,
        const QUrl & name )**

        Reimplements: **QTextEdit::loadResource** (int type, const QUrl &name).

        This function is called when the document is loaded and for each image
        in the document. The **type** indicates the type of resource to be
        loaded. An invalid **QVariant**  is returned if the resource cannot be
        loaded.

        The default implementation ignores **type** and tries to locate the
        resources by interpreting **name** as a file name. If it is not an
        absolute path it tries to find the file in the paths of the
        **searchPaths**  property and in the same directory as the current
        source. On success, the result is a **QVariant**  that stores a
        **QByteArray**  with the contents of the file.

        If you reimplement this function, you can return other **QVariant**
        types. The table below shows which variant types are supported depending
        on the resource type:

        ResourceType**QMetaType::Type**
        **QTextDocument::HtmlResource**
        **QString**  or **QByteArray**
        **QTextDocument::ImageResource**
        **QImage** , **QPixmap**  or **QByteArray**
        **QTextDocument::StyleSheetResource** **QString**  or **QByteArray**
        **QTextDocument::MarkdownResource** **QString**  or **QByteArray**
        """
        ...

    def setSearchPaths(self, paths: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#searchPaths-prop

        **searchPaths : QStringList**

        This property holds the search paths used by the text browser to find
        supporting content

        **QTextBrowser**  uses this list to locate images and documents.

        By default, this property contains an empty string list.

        **Access functions:**

        QStringList **searchPaths** () const
        void **setSearchPaths** (const
        QStringList & **paths** )
        """
        ...

    def searchPaths(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#searchPaths-prop

        **searchPaths : QStringList**

        This property holds the search paths used by the text browser to find
        supporting content

        **QTextBrowser**  uses this list to locate images and documents.

        By default, this property contains an empty string list.

        **Access functions:**

        QStringList **searchPaths** () const
        void **setSearchPaths** (const
        QStringList & **paths** )
        """
        ...

    def source(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#source-prop

        **source : QUrl**

        This property holds the name of the displayed document.

        This is a an invalid url if no document is displayed or if the source is
        unknown.

        When setting this property **QTextBrowser**  tries to find a document
        with the specified name in the paths of the **searchPaths**  property
        and directory of the current source, unless the value is an absolute
        file path. It also checks for optional anchors and scrolls the document
        accordingly

        If the first tag in the document is `<qt type=detail>`, the document is
        displayed as a popup rather than as new document in the browser window
        itself. Otherwise, the document is displayed normally in the text
        browser with the text set to the contents of the named document with
        **QTextDocument::setHtml** () or **QTextDocument::setMarkdown** (),
        depending on whether the filename ends with any of the known Markdown
        file extensions.

        If you would like to avoid automatic type detection and specify the type
        explicitly, call **setSource** () rather than setting this property.

        By default, this property contains an empty URL.

        **Access functions:**

        QUrl **source** () const
        void ****setSource** ** (const QUrl & **url**
        , QTextDocument::ResourceType **type** = QTextDocument::UnknownResource)
        """
        ...

    @property
    def anchorClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#anchorClicked

        **[signal] void QTextBrowser::anchorClicked(const QUrl & link )**

        This signal is emitted when the user clicks an anchor. The URL referred
        to by the anchor is passed in **link**.

        Note that the browser will automatically handle navigation to the
        location specified by **link** unless the **openLinks**  property is set
        to false or you call **setSource** () in a slot connected. This
        mechanism is used to override the default navigation features of the
        browser.
        """
        ...

    @property
    def backwardAvailable(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#backwardAvailable

        **[signal] void QTextBrowser::backwardAvailable(bool available )**

        This signal is emitted when the availability of **backward** () changes.
        **available** is false when the user is at **home** (); otherwise it is
        true.
        """
        ...

    @property
    def forwardAvailable(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#forwardAvailable

        **[signal] void QTextBrowser::forwardAvailable(bool available )**

        This signal is emitted when the availability of **forward** () changes.
        **available** is true after the user navigates **backward** () and false
        when the user navigates or goes **forward** ().
        """
        ...

    @property
    def highlighted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#highlighted

        **[signal] void QTextBrowser::highlighted(const QUrl & link )**

        This signal is emitted when the user has selected but not activated an
        anchor in the document. The URL referred to by the anchor is passed in
        **link**.
        """
        ...

    @property
    def historyChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#historyChanged

        **[signal] void QTextBrowser::historyChanged()**

        This signal is emitted when the history changes.

        **See also** **historyTitle** () and **historyUrl** ().
        """
        ...

    @property
    def sourceChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextbrowser.html#sourceChanged

        **[signal] void QTextBrowser::sourceChanged(const QUrl & src )**

        This signal is emitted when the source has changed, **src** being the
        new source.

        Source changes happen both programmatically when calling **setSource**
        (), **forward** (), **backward** () or **home** () or when the user
        clicks on links or presses the equivalent key sequences.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtDesigner import *


class QDesignerCustomWidgetCollectionInterface(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdesignercustomwidgetcollectioninterface.html

    **Detailed Description**

    When implementing a custom widget plugin, you build it as a separate
    library. If you want to include several custom widget plugins in the same
    library, you must in addition subclass
    QDesignerCustomWidgetCollectionInterface.

    QDesignerCustomWidgetCollectionInterface contains one single function
    returning a list of the collection's **QDesignerCustomWidgetInterface**
    objects. For example, if you have several custom widgets `CustomWidgetOne`,
    `CustomWidgetTwo` and `CustomWidgetThree`, the class definition may look
    like this:

    #include customwidgetoneinterface.h
        #include customwidgettwointerface.h
    #include customwidgetthreeinterface.h

        #include
    <QtDesigner/qtdesigner.h>
        #include <QtCore/qplugin.h>

        class
    MyCustomWidgets: public **QObject** , public
    **QDesignerCustomWidgetCollectionInterface**
        {
            Q_OBJECT
    Q_PLUGIN_METADATA(IID "org.qt-
    project.Qt.QDesignerCustomWidgetCollectionInterface")
    Q_INTERFACES(**QDesignerCustomWidgetCollectionInterface** )

        public:
    MyCustomWidgets(**QObject**  *parent = 0);

            **QList**
    <**QDesignerCustomWidgetInterface** *> customWidgets() const override;
    private:
            **QList** <**QDesignerCustomWidgetInterface** *> widgets;
    };

    In the class constructor you add the interfaces to your custom widgets to
    the list which you return in the **customWidgets** () function:

    MyCustomWidgets::MyCustomWidgets(**QObject**  *parent)
                :
    **QObject** (parent)
        {
            widgets.append(new
    CustomWidgetOneInterface(this));
            widgets.append(new
    CustomWidgetTwoInterface(this));
            widgets.append(new
    CustomWidgetThreeInterface(this));
        }

        **QList**
    <**QDesignerCustomWidgetInterface** *> MyCustomWidgets::customWidgets()
    const
        {
            return widgets;
        }

    Note that instead of exporting each custom widget plugin using the
    **Q_PLUGIN_METADATA** () macro, you export the entire collection. The
    **Q_PLUGIN_METADATA** () macro ensures that **Qt Designer** can access and
    construct the custom widgets. Without this macro, there is no way for **Qt
    Designer** to use them.

    **See also** **QDesignerCustomWidgetInterface**  and **Creating Custom
    Widgets for Qt Designer** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QDesignerCustomWidgetCollectionInterface") -> None:
        ...

    def customWidgets(self) -> typing.List[QDesignerCustomWidgetInterface]:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetcollectioninterface.html#cus
        tomWidgets

        **[pure virtual] QList<QDesignerCustomWidgetInterface *>
        QDesignerCustomWidgetCollectionInterface::customWidgets() const**

        Returns a list of interfaces to the collection's custom widgets.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQml import *


class QQmlContext(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qqmlcontext.html

    **Detailed Description**

    Contexts allow data to be exposed to the QML components instantiated by the
    QML engine.

    Each QQmlContext contains a set of properties, distinct from its **QObject**
    properties, that allow data to be explicitly bound to a context by name. The
    context properties are defined and updated by calling
    **QQmlContext::setContextProperty** (). The following example shows a Qt
    model being bound to a context and then accessed from a QML file.

    **QQmlEngine**  engine;
        **QStringListModel**  modelData;
    **QQmlContext**  *context = new **QQmlContext** (engine.rootContext());
    context->setContextProperty("myModel", &modelData);
    **QQmlComponent**  component(&engine);
        component.setData("import QtQuick
    2.0; ListView { model: myModel }", **QUrl** ());
        **QObject**  *window =
    component.create(context);

    **Note:** It is the responsibility of the creator to delete any QQmlContext
    it constructs. If the `context` object in the example is no longer needed
    when the `window` component instance is destroyed, the `context` must be
    destroyed explicitly. The simplest way to ensure this is to set `window` as
    the parent of `context`.

    To simplify binding and maintaining larger data sets, a context object can
    be set on a QQmlContext. All the properties of the context object are
    available by name in the context, as though they were all individually added
    through calls to **QQmlContext::setContextProperty** (). Changes to the
    property's values are detected through the property's notify signal. Setting
    a context object is both faster and easier than manually adding and
    maintaining context property values.

    The following example has the same effect as the previous one, but it uses a
    context object.

    class MyDataSet : public **QObject**  {
            // ...
    Q_PROPERTY(**QAbstractItemModel**  *myModel READ model NOTIFY modelChanged)
    // ...
        };

        MyDataSet myDataSet;
        **QQmlEngine**  engine;
    **QQmlContext**  *context = new **QQmlContext** (engine.rootContext());
    context->setContextObject(&myDataSet);

        **QQmlComponent**
    component(&engine);
        component.setData("import QtQuick 2.0; ListView {
    model: myModel }", **QUrl** ());
        component.create(context);

    All properties added explicitly by **QQmlContext::setContextProperty** ()
    take precedence over the context object's properties.

    **The Context Hierarchy**

    Contexts form a hierarchy. The root of this hierarchy is the QML engine's
    **root context** . Child contexts inherit the context properties of their
    parents; if a child context sets a context property that already exists in
    its parent, the new context property overrides that of the parent.

    The following example defines two contexts - `context1` and `context2`. The
    second context overrides the "b" context property inherited from the first
    with a new value.

    **QQmlEngine**  engine;
        **QQmlContext**  *context1 = new **QQmlContext**
    (engine.rootContext());
        **QQmlContext**  *context2 = new **QQmlContext**
    (context1);

        context1->setContextProperty("a", 9001);
    context1->setContextProperty("b", 9001);
    context2->setContextProperty("b", 42);

    While QML objects instantiated in a context are not strictly owned by that
    context, their bindings are. If a context is destroyed, the property
    bindings of outstanding QML objects will stop evaluating.

    **Warning:** Setting the context object or adding new context properties
    after an object has been created in that context is an expensive operation
    (essentially forcing all bindings to reevaluate). Thus whenever possible you
    should complete "setup" of the context before using it to create any
    objects.

    **See also** **Exposing Attributes of C++ Types to QML** .
    """

    class PropertyPair(PyQt6.sip.simplewrapper):
        name: str = ...
        value: typing = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QQmlContext.PropertyPair") -> None:
            ...

    @typing.overload
    def __init__(
        self, engine: QQmlEngine, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#QQmlContext

        **QQmlContext::QQmlContext(QQmlEngine * engine , QObject * parent =
        nullptr)**

        Create a new QQmlContext as a child of **engine** 's root context, and
        the **QObject**  **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        parentContext: "QQmlContext",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#QQmlContext-1

        **QQmlContext::QQmlContext(QQmlContext * parentContext , QObject *
        parent = nullptr)**

        Create a new QQmlContext with the given **parentContext** , and the
        **QObject**  **parent**.
        """
        ...

    def objectForName(self, a0: str) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#objectForName

        **[since 6.2] QObject *QQmlContext::objectForName(const QString & name )
        const**

        Returns the object for a given **name** in this context. Returns nullptr
        if **name** is not available in the context or if the value associated
        with **name** is not a **QObject** . Objects are named by
        **setContextProperty** (), or as properties of a context object, or by
        ids in the case of QML created contexts. In contrast to
        **contextProperty** (), this method does not traverse the context
        hierarchy. If the name is not found in the current context, nullptr is
        returned.

        This function was introduced in Qt 6.2.

        **See also** **contextProperty** () and **nameForObject** ().
        """
        ...

    def setContextProperties(
        self, properties: typing.Iterable["QQmlContext.PropertyPair"]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#setContextProperties

        **[since 5.11] void QQmlContext::setContextProperties(const
        QList<QQmlContext::PropertyPair> & properties )**

        Set a batch of **properties** on this context.

        Setting all properties in one batch avoids unnecessary refreshing
        expressions, and is therefore recommended instead of calling
        **setContextProperty** () for each individual property.

        This function was introduced in Qt 5.11.

        **See also** **QQmlContext::setContextProperty** ().
        """
        ...

    def baseUrl(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#baseUrl

        **QUrl QQmlContext::baseUrl() const**

        Returns the base url of the component, or the containing component if
        none is set.

        **See also** **setBaseUrl** ().
        """
        ...

    def setBaseUrl(self, a0: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#setBaseUrl

        **void QQmlContext::setBaseUrl(const QUrl & baseUrl )**

        Explicitly sets the url **resolvedUrl** () will use for relative
        references to **baseUrl**.

        Calling this function will override the url of the containing component
        used by default.

        **See also** **baseUrl** () and **resolvedUrl** ().
        """
        ...

    def resolvedUrl(self, a0: QtCore.QUrl) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#resolvedUrl

        **QUrl QQmlContext::resolvedUrl(const QUrl & src ) const**

        Resolves the URL **src** relative to the URL of the containing
        component.

        **See also** **QQmlEngine::baseUrl** () and **setBaseUrl** ().
        """
        ...

    def nameForObject(self, a0: QtCore.QObject) -> str:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#nameForObject

        **QString QQmlContext::nameForObject(const QObject * object ) const**

        Returns the name of **object** in this context, or an empty string if
        **object** is not named in the context. Objects are named by
        **setContextProperty** (), or as properties of a context object, or by
        ids in the case of QML created contexts.

        If the object has multiple names, the first is returned.

        In contrast to **contextProperty** (), this method does not traverse the
        context hierarchy. If the name is not found in the current context, an
        empty String is returned.

        **See also** **contextProperty** () and **objectForName** ().
        """
        ...

    @typing.overload
    def setContextProperty(self, a0: str, a1: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#setContextProperty

        **void QQmlContext::setContextProperty(const QString & name , QObject *
        value )**

        Set the **value** of the **name** property on this context.

        **QQmlContext**  does **not** take ownership of **value**.

        **See also** **contextProperty** ().
        """
        ...

    @typing.overload
    def setContextProperty(self, a0: str, a1: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#setContextProperty-1

        **void QQmlContext::setContextProperty(const QString & name , const
        QVariant & value )**

        Set a the **value** of the **name** property on this context.
        """
        ...

    def contextProperty(self, a0: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#contextProperty

        **QVariant QQmlContext::contextProperty(const QString & name ) const**

        Returns the value of the **name** property for this context as a
        **QVariant** . If you know that the property you're looking for is a
        **QObject**  assigned using a QML id in the current context,
        **objectForName** () is more convenient and faster. In contrast to
        **objectForName** () and **nameForObject** (), this method does traverse
        the context hierarchy and searches in parent contexts if the **name** is
        not found in the current one. It also considers any **contextObject** ()
        you may have set.

        **See also** **setContextProperty** (), **objectForName** (),
        **nameForObject** (), and **contextObject** ().
        """
        ...

    def setContextObject(self, a0: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#setContextObject

        **void QQmlContext::setContextObject(QObject * object )**

        Set the context **object**.

        **See also** **contextObject** ().
        """
        ...

    def contextObject(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#contextObject

        **QObject *QQmlContext::contextObject() const**

        Return the context object, or `nullptr` if there is no context object.

        **See also** **setContextObject** ().
        """
        ...

    def parentContext(self) -> "QQmlContext":
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#parentContext

        **QQmlContext *QQmlContext::parentContext() const**

        Return the context's parent **QQmlContext** , or `nullptr` if this
        context has no parent or if the parent has been destroyed.
        """
        ...

    def engine(self) -> QQmlEngine:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#engine

        **QQmlEngine *QQmlContext::engine() const**

        Return the context's **QQmlEngine** , or `nullptr` if the context has no
        **QQmlEngine**  or the **QQmlEngine**  was destroyed.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlcontext.html#isValid

        **bool QQmlContext::isValid() const**

        Returns whether the context is valid.

        To be valid, a context must have a engine, and it's **contextObject**
        (), if any, must not have been deleted.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtDBus import *
import enum


class QDBusServiceWatcher(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qdbusservicewatcher.html

    **Detailed Description**

    A QDBusServiceWatcher object can be used to notify the application about an
    ownership change of a service name on the bus. It has three watch modes:

    * Watching for service registration only.
      * Watching for service
    unregistration only.
      * Watching for any kind of service ownership change
    (the default mode).

    Besides being created or deleted, services may change owners without a
    unregister/register operation happening. So the **serviceRegistered** () and
    **serviceUnregistered** () signals may not be emitted if that happens.

    This class is more efficient than using the
    QDBusConnectionInterface::serviceOwnerChanged() signal because it allows one
    to receive only the signals for which the class is interested in.

    Ending a service name with the character '*' will match all service names
    within the specified namespace.

    For example "com.example.backend1*" will match

    * com.example.backend1
      * com.example.backend1.foo
      *
    com.example.backend1.foo.bar

    Substrings in the same domain will not be matched, i.e
    "com.example.backend12".

    **See also** **QDBusConnection** .
    """

    class WatchModeFlag(enum.Flag):
        WatchForRegistration: QDBusServiceWatcher = ...
        WatchForUnregistration: QDBusServiceWatcher = ...
        WatchForOwnerChange: QDBusServiceWatcher = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#QDBusServiceWatcher

        **QDBusServiceWatcher::QDBusServiceWatcher(QObject * parent = nullptr)**

        Creates a QDBusServiceWatcher object. Note that until you set a
        connection with **setConnection** (), this object will not emit any
        signals.

        The **parent** parameter is passed to **QObject**  to set the parent of
        this object.
        """
        ...

    @typing.overload
    def __init__(
        self,
        service: str,
        connection: QDBusConnection,
        watchMode: "QDBusServiceWatcher.WatchModeFlag" = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#QDBusServiceWatcher-1

        **QDBusServiceWatcher::QDBusServiceWatcher(const QString & service ,
        const QDBusConnection & connection , QDBusServiceWatcher::WatchMode
        watchMode = WatchForOwnerChange, QObject * parent = nullptr)**

        Creates a QDBusServiceWatcher object and attaches it to the
        **connection** connection. Also, this function immediately starts
        watching for **watchMode** changes to service **service**.

        The **parent** parameter is passed to **QObject**  to set the parent of
        this object.
        """
        ...

    def setConnection(self, connection: QDBusConnection) -> None:
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#setConnection

        **void QDBusServiceWatcher::setConnection(const QDBusConnection &
        connection )**

        Sets the D-Bus connection that this object is attached to be
        **connection**. All services watched will be transferred to this
        connection.

        Note that **QDBusConnection**  objects are reference counted:
        **QDBusServiceWatcher**  will keep a reference for this connection while
        it exists. The connection is not closed until the reference count drops
        to zero, so this will ensure that any notifications are received while
        this **QDBusServiceWatcher**  object exists.

        **See also** **connection** ().
        """
        ...

    def connection(self) -> QDBusConnection:
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#connection

        **QDBusConnection QDBusServiceWatcher::connection() const**

        Returns the **QDBusConnection**  that this object is attached to.

        **See also** **setConnection** ().
        """
        ...

    def setWatchMode(self, mode: "QDBusServiceWatcher.WatchModeFlag") -> None:
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#watchMode-prop

        **[bindable] watchMode : WatchMode**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the current watch mode for this
        **QDBusServiceWatcher**  object.

        The default value for this property is
        QDBusServiceWatcher::WatchForOwnershipChange.
        """
        ...

    def watchMode(self) -> "QDBusServiceWatcher.WatchModeFlag":
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#watchMode-prop

        **[bindable] watchMode : WatchMode**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the current watch mode for this
        **QDBusServiceWatcher**  object.

        The default value for this property is
        QDBusServiceWatcher::WatchForOwnershipChange.
        """
        ...

    def removeWatchedService(self, service: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#removeWatchedService

        **bool QDBusServiceWatcher::removeWatchedService(const QString & service
        )**

        Removes the **service** from the list of services being watched by this
        object. Note that D-Bus notifications are asynchronous, so there may
        still be signals pending delivery about **service**. Those signals will
        still be emitted whenever the D-Bus messages are processed.

        Removes any existing binding of **watchedServices** .

        This function returns `true` if any services were removed.
        """
        ...

    def addWatchedService(self, newService: str) -> None:
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#addWatchedService

        **void QDBusServiceWatcher::addWatchedService(const QString & newService
        )**

        Adds **newService** to the list of services to be watched by this
        object. This function is more efficient than **setWatchedServices** ()
        and should be used whenever possible to add services.

        Removes any existing binding of **watchedServices** .
        """
        ...

    def setWatchedServices(self, services: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#setWatchedServices

        **void QDBusServiceWatcher::setWatchedServices(const QStringList &
        services )**

        Sets the list of D-Bus services being watched to be **services**.

        Note that setting the entire list means removing all previous rules for
        watching services and adding new ones. This is an expensive operation
        and should be avoided, if possible. Instead, use **addWatchedService**
        () and **removeWatchedService** () if you can to manipulate entries in
        the list.

        Removes any existing binding of **watchedServices** .

        **Note:** Setter function for property **watchedServices** .

        **See also** **watchedServices** ().
        """
        ...

    def watchedServices(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#watchedServices

        **QStringList QDBusServiceWatcher::watchedServices() const**

        Returns the list of D-Bus services that are being watched.

        **Note:** Getter function for property watchedServices.

        **See also** **setWatchedServices** ().
        """
        ...

    @property
    def serviceOwnerChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#serviceOwnerChanged

        **[signal] void QDBusServiceWatcher::serviceOwnerChanged(const QString &
        serviceName , const QString & oldOwner , const QString & newOwner )**

        This signal is emitted whenever this object detects that there was a
        service ownership change relating to the **serviceName** service. The
        **oldOwner** parameter contains the old owner name and **newOwner** is
        the new owner. Both **oldOwner** and **newOwner** are unique connection
        names.

        Note that this signal is also emitted whenever the **serviceName**
        service was registered or unregistered. If it was registered,
        **oldOwner** will contain an empty string, whereas if it was
        unregistered, **newOwner** will contain an empty string.

        If you need only to find out if the service is registered or
        unregistered only, without being notified that the ownership changed,
        consider using the specific modes for those operations. This class is
        more efficient if you use the more specific modes.

        **See also** **serviceRegistered** () and **serviceUnregistered** ().
        """
        ...

    @property
    def serviceRegistered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#serviceRegistered

        **[signal] void QDBusServiceWatcher::serviceRegistered(const QString &
        serviceName )**

        This signal is emitted whenever this object detects that the service
        **serviceName** became available on the bus.

        **See also** **serviceUnregistered** () and **serviceOwnerChanged** ().
        """
        ...

    @property
    def serviceUnregistered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdbusservicewatcher.html#serviceUnregistered

        **[signal] void QDBusServiceWatcher::serviceUnregistered(const QString &
        serviceName )**

        This signal is emitted whenever this object detects that the service
        **serviceName** was unregistered from the bus and is no longer
        available.

        **See also** **serviceRegistered** () and **serviceOwnerChanged** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QFocusFrame(QWidget):
    """
    https://doc.qt.io/qt-6/qfocusframe.html

    **Detailed Description**

    Normally an application will not need to create its own QFocusFrame as
    **QStyle**  will handle this detail for you. A style writer can optionally
    use a QFocusFrame to have a focus area outside of the widget's paintable
    geometry. In this way space need not be reserved for the widget to have
    focus but only set on a **QWidget**  with **QFocusFrame::setWidget** . It
    is, however, legal to create your own QFocusFrame on a custom widget and set
    its geometry manually via **QWidget::setGeometry**  however you will not get
    auto-placement when the focused widget changes size or placement.
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qfocusframe.html#QFocusFrame

        **QFocusFrame::QFocusFrame(QWidget * parent = nullptr)**

        Constructs a QFocusFrame.

        The focus frame will not monitor **parent** for updates but rather can
        be placed manually or by using **QFocusFrame::setWidget** . A
        QFocusFrame sets **Qt::WA_NoChildEventsForParent**  attribute; as a
        result the parent will not receive a **QEvent::ChildAdded**  event, this
        will make it possible to manually set the geometry of the QFocusFrame
        inside of a **QSplitter**  or other child event monitoring widget.

        **See also** **QFocusFrame::setWidget** ().
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qfocusframe.html#paintEvent

        **[override virtual protected] void QFocusFrame::paintEvent(QPaintEvent
        *)**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qfocusframe.html#event

        **[override virtual protected] bool QFocusFrame::event(QEvent * e )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def eventFilter(self, a0: QtCore.QObject, a1: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qfocusframe.html#eventFilter

        **[override virtual protected] bool QFocusFrame::eventFilter(QObject * o
        , QEvent * e )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).
        """
        ...

    def initStyleOption(self, option: "QStyleOption") -> None:
        """
        https://doc.qt.io/qt-6/qfocusframe.html#initStyleOption

        **[virtual protected] void QFocusFrame::initStyleOption(QStyleOption *
        option ) const**

        Initialize **option** with the values from this **QFocusFrame** . This
        method is useful for subclasses when they need a **QStyleOption** , but
        don't want to fill in all the information themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def widget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qfocusframe.html#widget

        **QWidget *QFocusFrame::widget() const**

        Returns the currently monitored widget for automatically resize and
        update.

        **See also** **QFocusFrame::setWidget** ().
        """
        ...

    def setWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qfocusframe.html#setWidget

        **void QFocusFrame::setWidget(QWidget * widget )**

        **QFocusFrame**  will track changes to **widget** and resize itself
        automatically. If the monitored widget's parent changes, **QFocusFrame**
        will follow the widget and place itself around the widget automatically.
        If the monitored widget is deleted, **QFocusFrame**  will set it to
        zero.

        **See also** **QFocusFrame::widget** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtDBus import *
import enum


class QDBusMessage(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbusmessage.html

    **Detailed Description**

    This object can represent any of the four different types of messages
    (**MessageType** ) that can occur on the bus:

    * Method calls
      * Method return values
      * Signal emissions
      * Error codes

    Objects of this type are created with the static **createError** (),
    **createMethodCall** () and **createSignal** () functions. Use the
    **QDBusConnection::send** () function to send the messages.
    """

    class MessageType(enum.Enum):
        InvalidMessage: QDBusMessage = ...
        MethodCallMessage: QDBusMessage = ...
        ReplyMessage: QDBusMessage = ...
        ErrorMessage: QDBusMessage = ...
        SignalMessage: QDBusMessage = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#QDBusMessage

        **QDBusMessage::QDBusMessage()**

        Constructs an empty, invalid QDBusMessage object.

        **See also** **createError** (), **createMethodCall** (), and
        **createSignal** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QDBusMessage") -> None:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#QDBusMessage-1

        **QDBusMessage::QDBusMessage(const QDBusMessage & other )**

        Constructs a copy of the object given by **other**.

        Note: QDBusMessage objects are shared. Modifications made to the copy
        will affect the original one as well. See **setDelayedReply** () for
        more information.
        """
        ...

    def isInteractiveAuthorizationAllowed(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#isInteractiveAuthorizationAllow
        ed

        **[since 5.12] bool QDBusMessage::isInteractiveAuthorizationAllowed()
        const**

        Returns the interactive authorization allowed flag, as set by
        **setInteractiveAuthorizationAllowed** (). By default this flag is false
        and the other end is expected to make any authorization decisions non-
        interactively and promptly.

        This function was introduced in Qt 5.12.

        **See also** **setInteractiveAuthorizationAllowed** ().
        """
        ...

    def setInteractiveAuthorizationAllowed(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#setInteractiveAuthorizationAllo
        wed

        **[since 5.12] void
        QDBusMessage::setInteractiveAuthorizationAllowed(bool enable )**

        Sets the interactive authorization flag to **enable**. This flag only
        makes sense for method call messages, where it tells the D-Bus server
        that the caller of the method is prepared to wait for interactive
        authorization to take place (for instance via Polkit) before the actual
        method is processed.

        By default this flag is false and the other end is expected to make any
        authorization decisions non-interactively and promptly.

        The `org.freedesktop.DBus.Error.InteractiveAuthorizationRequired` error
        indicates that authorization failed, but could have succeeded if this
        flag had been set.

        This function was introduced in Qt 5.12.

        **See also** **isInteractiveAuthorizationAllowed** ().
        """
        ...

    @staticmethod
    def createTargetedSignal(
        service: str, path: str, interface: str, name: str
    ) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#createTargetedSignal

        **[static, since 5.6] QDBusMessage
        QDBusMessage::createTargetedSignal(const QString & service , const
        QString & path , const QString & interface , const QString & name )**

        Constructs a new DBus message with the given **path** , **interface**
        and **name** , representing a signal emission to a specific destination.

        A DBus signal is emitted from one application and is received only by
        the application owning the destination **service** name.

        The **QDBusMessage**  object that is returned can be sent using the
        **QDBusConnection::send** () function.

        This function was introduced in Qt 5.6.
        """
        ...

    def swap(self, other: "QDBusMessage") -> None:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#swap

        **void QDBusMessage::swap(QDBusMessage & other )**

        Swaps this **QDBusMessage**  instance with **other**.
        """
        ...

    def arguments(self) -> typing.List[typing.Any]:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#arguments

        **QList<QVariant> QDBusMessage::arguments() const**

        Returns the list of arguments that are going to be sent or were received
        from D-Bus.

        **See also** **setArguments** ().
        """
        ...

    def setArguments(self, arguments: typing.Iterable[typing.Any]) -> None:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#setArguments

        **void QDBusMessage::setArguments(const QList<QVariant> & arguments )**

        Sets the arguments that are going to be sent over D-Bus to
        **arguments**. Those will be the arguments to a method call or the
        parameters in the signal.

        **See also** **arguments** ().
        """
        ...

    def autoStartService(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#autoStartService

        **bool QDBusMessage::autoStartService() const**

        Returns the auto start flag, as set by **setAutoStartService** (). By
        default, this flag is true, which means Qt D-Bus will auto start a
        service, if it is not running already.

        **See also** **setAutoStartService** ().
        """
        ...

    def setAutoStartService(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#setAutoStartService

        **void QDBusMessage::setAutoStartService(bool enable )**

        Sets the auto start flag to **enable**. This flag only makes sense for
        method call messages, where it tells the D-Bus server to either auto
        start the service responsible for the service name, or not to auto start
        it.

        By default this flag is true, i.e. a service is autostarted. This means:

        When the service that this method call is sent to is already running,
        the method call is sent to it. If the service is not running yet, the
        D-Bus daemon is requested to autostart the service that is assigned to
        this service name. This is handled by .service files that are placed in
        a directory known to the D-Bus server. These files then each contain a
        service name and the path to a program that should be executed when this
        service name is requested.

        **See also** **autoStartService** ().
        """
        ...

    def isDelayedReply(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#isDelayedReply

        **bool QDBusMessage::isDelayedReply() const**

        Returns the delayed reply flag, as set by **setDelayedReply** (). By
        default, this flag is false, which means Qt D-Bus will generate
        automatic replies when necessary.
        """
        ...

    def setDelayedReply(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#setDelayedReply

        **void QDBusMessage::setDelayedReply(bool enable ) const**

        Sets whether the message will be replied later (if **enable** is true)
        or if an automatic reply should be generated by Qt D-Bus (if **enable**
        is false).

        In D-Bus, all method calls must generate a reply to the caller, unless
        the caller explicitly indicates otherwise (see **isReplyRequired** ()).
        **QtDBus**  automatically generates such replies for any slots being
        called, but it also allows slots to indicate whether they will take
        responsibility of sending the reply at a later time, after the function
        has finished processing.

        **See also** **isDelayedReply** () and **Delayed Replies** .
        """
        ...

    def isReplyRequired(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#isReplyRequired

        **bool QDBusMessage::isReplyRequired() const**

        Returns the flag that indicates if this message should see a reply or
        not. This is only meaningful for **method call messages** : any other
        kind of message cannot have replies and this function will always return
        false for them.
        """
        ...

    def signature(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#signature

        **QString QDBusMessage::signature() const**

        Returns the signature of the signal that was received or for the output
        arguments of a method call.
        """
        ...

    def type(self) -> "QDBusMessage.MessageType":
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#type

        **QDBusMessage::MessageType QDBusMessage::type() const**

        Returns the message type.
        """
        ...

    def errorMessage(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#errorMessage

        **QString QDBusMessage::errorMessage() const**

        Returns the human-readable message associated with the error that was
        received.
        """
        ...

    def errorName(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#errorName

        **QString QDBusMessage::errorName() const**

        Returns the name of the error that was received.
        """
        ...

    def member(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#member

        **QString QDBusMessage::member() const**

        Returns the name of the signal that was emitted or the name of the
        method that was called.
        """
        ...

    def interface(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#interface

        **QString QDBusMessage::interface() const**

        Returns the interface of the method being called (in the case of a
        method call) or of the signal being received from.
        """
        ...

    def path(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#path

        **QString QDBusMessage::path() const**

        Returns the path of the object that this message is being sent to (in
        the case of a method call) or being received from (for a signal).
        """
        ...

    def service(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#service

        **QString QDBusMessage::service() const**

        Returns the name of the service or the bus address of the remote method
        call.
        """
        ...

    @typing.overload
    def createErrorReply(self, name: str, msg: str) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#createErrorReply

        **QDBusMessage QDBusMessage::createErrorReply(const QString & name ,
        const QString & msg ) const**

        Constructs a new DBus message representing an error reply message, with
        the given **name** and **msg**.
        """
        ...

    @typing.overload
    def createErrorReply(self, error: QDBusError) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#createErrorReply-1

        **QDBusMessage QDBusMessage::createErrorReply(const QDBusError & error )
        const**

        Constructs a new DBus message representing an error reply message, from
        the given **error** object.
        """
        ...

    @typing.overload
    def createErrorReply(self, type: QDBusError.ErrorType, msg: str) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#createErrorReply-2

        **QDBusMessage QDBusMessage::createErrorReply(QDBusError::ErrorType type
        , const QString & msg ) const**

        Constructs a new DBus reply message for the error type **type** using
        the message **msg**. Returns the DBus message.
        """
        ...

    @typing.overload
    def createReply(
        self, arguments: typing.Iterable[typing.Any] = ...
    ) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#createReply

        **QDBusMessage QDBusMessage::createReply(const QList<QVariant> &
        arguments = QList<QVariant>()) const**

        Constructs a new DBus message representing a reply, with the given
        **arguments**.
        """
        ...

    @typing.overload
    def createReply(self, argument: typing.Any) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#createReply-1

        **QDBusMessage QDBusMessage::createReply(const QVariant & argument )
        const**

        Constructs a new DBus message representing a reply, with the given
        **argument**.
        """
        ...

    @typing.overload
    @staticmethod
    def createError(name: str, msg: str) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#createError

        **[static] QDBusMessage QDBusMessage::createError(const QString & name ,
        const QString & msg )**

        Constructs a new DBus message representing an error, with the given
        **name** and **msg**.
        """
        ...

    @typing.overload
    @staticmethod
    def createError(error: QDBusError) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#createError-1

        **[static] QDBusMessage QDBusMessage::createError(const QDBusError &
        error )**

        Constructs a new DBus message representing the given **error**.
        """
        ...

    @typing.overload
    @staticmethod
    def createError(type: QDBusError.ErrorType, msg: str) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#createError-2

        **[static] QDBusMessage QDBusMessage::createError(QDBusError::ErrorType
        type , const QString & msg )**

        Constructs a new DBus message for the error type **type** using the
        message **msg**. Returns the DBus message.
        """
        ...

    @staticmethod
    def createMethodCall(
        service: str, path: str, interface: str, method: str
    ) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#createMethodCall

        **[static] QDBusMessage QDBusMessage::createMethodCall(const QString &
        service , const QString & path , const QString & interface , const
        QString & method )**

        Constructs a new DBus message representing a method call. A method call
        always informs its destination address ( **service** , **path** ,
        **interface** and **method** ).

        The DBus bus allows calling a method on a given remote object without
        specifying the destination interface, if the method name is unique.
        However, if two interfaces on the remote object export the same method
        name, the result is undefined (one of the two may be called or an error
        may be returned).

        When using DBus in a peer-to-peer context (i.e., not on a bus), the
        **service** parameter is optional.

        The **QDBusInterface**  class provides a simpler abstraction to
        synchronous method calling.

        This function returns a **QDBusMessage**  object that can be sent with
        **QDBusConnection::call** ().
        """
        ...

    @staticmethod
    def createSignal(path: str, interface: str, name: str) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusmessage.html#createSignal

        **[static] QDBusMessage QDBusMessage::createSignal(const QString & path
        , const QString & interface , const QString & name )**

        Constructs a new DBus message with the given **path** , **interface**
        and **name** , representing a signal emission.

        A DBus signal is emitted from one application and is received by all
        applications that are listening for that signal from that interface.

        The **QDBusMessage**  object that is returned can be sent using the
        **QDBusConnection::send** () function.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QFile(QFileDevice):
    """
    https://doc.qt.io/qt-6/qfile.html

    **Detailed Description**

    QFile is an I/O device for reading and writing text and binary files and
    **resources** . A QFile may be used by itself or, more conveniently, with a
    **QTextStream**  or **QDataStream** .

    The file name is usually passed in the constructor, but it can be set at any
    time using **setFileName** (). QFile expects the file separator to be '/'
    regardless of operating system. The use of other separators (e.g., '\\') is
    not supported.

    You can check for a file's existence using **exists** (), and remove a file
    using **remove** (). (More advanced file system related operations are
    provided by **QFileInfo**  and **QDir** .)

    The file is opened with **open** (), closed with **close** (), and flushed
    with **flush** (). Data is usually read and written using **QDataStream**
    or **QTextStream** , but you can also call the **QIODevice** -inherited
    functions **read** (), **readLine** (), **readAll** (), **write** (). QFile
    also inherits **getChar** (), **putChar** (), and **ungetChar** (), which
    work one character at a time.

    The size of the file is returned by **size** (). You can get the current
    file position using **pos** (), or move to a new file position using
    **seek** (). If you've reached the end of the file, **atEnd** () returns
    `true`.

    **Reading Files Directly**

    The following example reads a text file line by line:

    **QFile**  file("in.txt");
            if (!file.open(**QIODevice** ::ReadOnly |
    **QIODevice** ::Text))
                return;

            while
    (!file.atEnd()) {
                **QByteArray**  line = file.readLine();
    process_line(line);
            }

    The QIODevice::Text flag passed to **open** () tells Qt to convert Windows-
    style line terminators ("\\r\\n") into C++-style terminators ("\\n"). By
    default, QFile assumes binary, i.e. it doesn't perform any conversion on the
    bytes stored in the file.

    **Using Streams to Read Files**

    The next example uses **QTextStream**  to read a text file line by line:

    **QFile**  file("in.txt");
            if (!file.open(**QIODevice** ::ReadOnly |
    **QIODevice** ::Text))
                return;

            **QTextStream**
    in(&file);
            while (!in.atEnd()) {
                **QString**  line =
    in.readLine();
                process_line(line);
            }

    **QTextStream**  takes care of converting the 8-bit data stored on disk into
    a 16-bit Unicode **QString** . By default, it assumes that the file is
    encoded in UTF-8. This can be changed using **QTextStream::setEncoding** ().

    To write text, we can use operator<<(), which is overloaded to take a
    **QTextStream**  on the left and various data types (including **QString** )
    on the right:

    **QFile**  file("out.txt");
            if (!file.open(**QIODevice** ::WriteOnly
    | **QIODevice** ::Text))
                return;

            **QTextStream**
    out(&file);
            out << "The magic number is: " << 49 << "\\n";

    **QDataStream**  is similar, in that you can use operator<<() to write data
    and operator>>() to read it back. See the class documentation for details.

    When you use QFile, **QFileInfo** , and **QDir**  to access the file system
    with Qt, you can use Unicode file names. On Unix, these file names are
    converted to an 8-bit encoding. If you want to use standard C++ APIs
    (`<cstdio>` or `<iostream>`) or platform-specific APIs to access files
    instead of QFile, you can use the **encodeName** () and **decodeName** ()
    functions to convert between Unicode file names and 8-bit file names.

    On Unix, there are some special system files (e.g. in `/proc`) for which
    **size** () will always return 0, yet you may still be able to read more
    data from such a file; the data is generated in direct response to you
    calling **read** (). In this case, however, you cannot use **atEnd** () to
    determine if there is more data to read (since **atEnd** () will return true
    for a file that claims to have size 0). Instead, you should either call
    **readAll** (), or call **read** () or **readLine** () repeatedly until no
    more data can be read. The next example uses **QTextStream**  to read
    `/proc/modules` line by line:

    **QFile**  file("/proc/modules");
            if (!file.open(**QIODevice**
    ::ReadOnly | **QIODevice** ::Text))
                return;
    **QTextStream**  in(&file);
            **QString**  line = in.readLine();
    while (!line.isNull()) {
                process_line(line);
                line =
    in.readLine();
            }

    **Signals**

    Unlike other **QIODevice**  implementations, such as **QTcpSocket** , QFile
    does not emit the **aboutToClose** (), **bytesWritten** (), or **readyRead**
    () signals. This implementation detail means that QFile is not suitable for
    reading and writing certain types of files, such as device files on Unix
    platforms.

    **Platform Specific Issues**

    File permissions are handled differently on Unix-like systems and Windows.
    In a non **writable**  directory on Unix-like systems, files cannot be
    created. This is not always the case on Windows, where, for instance, the
    'My Documents' directory usually is not writable, but it is still possible
    to create files in it.

    Qt's understanding of file permissions is limited, which affects especially
    the **QFile::setPermissions** () function. On Windows, Qt will set only the
    legacy read-only flag, and that only when none of the Write* flags are
    passed. Qt does not manipulate access control lists (ACLs), which makes this
    function mostly useless for NTFS volumes. It may still be of use for USB
    sticks that use VFAT file systems. POSIX ACLs are not manipulated, either.

    **See also** **QTextStream** , **QDataStream** , **QFileInfo** , **QDir** ,
    and **The Qt Resource System** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qfile.html#QFile

        **QFile::QFile()**

        Constructs a QFile object.
        """
        ...

    @typing.overload
    def __init__(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qfile.html#QFile-1

        **QFile::QFile(const QString & name )**

        Constructs a new file object to represent the file with the given
        **name**.
        """
        ...

    @typing.overload
    def __init__(self, parent: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qfile.html#QFile-2

        **[since 6.0] QFile::QFile(const std::filesystem::path & name )**

        Constructs a new file object to represent the file with the given
        **name**.

        This function was introduced in Qt 6.0.
        """
        ...

    @typing.overload
    def __init__(self, name: str, parent: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qfile.html#QFile-3

        **QFile::QFile(QObject * parent )**

        Constructs a new file object with the given **parent**.
        """
        ...

    @typing.overload
    def moveToTrash(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#moveToTrash

        **[since 5.15] bool QFile::moveToTrash()**

        Moves the file specified by **fileName** () to the trash. Returns `true`
        if successful, and sets the **fileName** () to the path at which the
        file can be found within the trash; otherwise returns `false`.

        **Note:** On systems where the system API doesn't report the location of
        the file in the trash, **fileName** () will be set to the null string
        once the file has been moved. On systems that don't have a trash can,
        this function always returns false.

        This function was introduced in Qt 5.15.
        """
        ...

    @typing.overload
    @staticmethod
    def moveToTrash(fileName: str) -> typing.Tuple[bool, str]:
        """
        https://doc.qt.io/qt-6/qfile.html#moveToTrash-1

        **[static, since 5.15] bool QFile::moveToTrash(const QString & fileName
        , QString * pathInTrash = nullptr)**

        This is an overloaded function.

        Moves the file specified by **fileName** () to the trash. Returns `true`
        if successful, and sets **pathInTrash** (if provided) to the path at
        which the file can be found within the trash; otherwise returns `false`.

        **Note:** On systems where the system API doesn't report the path of the
        file in the trash, **pathInTrash** will be set to the null string once
        the file has been moved. On systems that don't have a trash can, this
        function always returns false.

        This function was introduced in Qt 5.15.
        """
        ...

    @typing.overload
    def setPermissions(self, permissionSpec: QFileDevice.Permission) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#setPermissions

        **[override virtual] bool QFile::setPermissions(QFileDevice::Permissions
        permissions )**

        Reimplements: **QFileDevice::setPermissions** (QFileDevice::Permissions
        permissions).

        Sets the permissions for the file to the **permissions** specified.
        Returns `true` if successful, or `false` if the permissions cannot be
        modified.

        **Warning:** This function does not manipulate ACLs, which may limit its
        effectiveness.

        **See also** **permissions** () and **setFileName** ().
        """
        ...

    @typing.overload
    @staticmethod
    def setPermissions(filename: str, permissionSpec: QFileDevice.Permission) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#setPermissions-1

        **[static] bool QFile::setPermissions(const QString & fileName ,
        QFileDevice::Permissions permissions )**

        This is an overloaded function.

        Sets the permissions for **fileName** file to **permissions**.
        """
        ...

    @typing.overload
    def permissions(self) -> QFileDevice.Permission:
        """
        https://doc.qt.io/qt-6/qfile.html#permissions

        **[override virtual] QFileDevice::Permissions QFile::permissions()
        const**

        Reimplements: **QFileDevice::permissions() const** .

        **See also** **setPermissions** ().
        """
        ...

    @typing.overload
    @staticmethod
    def permissions(filename: str) -> QFileDevice.Permission:
        """
        https://doc.qt.io/qt-6/qfile.html#permissions-1

        **[static] QFileDevice::Permissions QFile::permissions(const QString &
        fileName )**

        This is an overloaded function.

        Returns the complete OR-ed together combination of QFile::Permission for
        **fileName**.
        """
        ...

    @typing.overload
    def resize(self, sz: int) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#resize

        **[override virtual] bool QFile::resize(qint64 sz )**

        Reimplements: **QFileDevice::resize** (qint64 sz).
        """
        ...

    @typing.overload
    @staticmethod
    def resize(filename: str, sz: int) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#resize-1

        **[static] bool QFile::resize(const QString & fileName , qint64 sz )**

        This is an overloaded function.

        Sets **fileName** to size (in bytes) **sz**. Returns `true` if the
        resize succeeds; false otherwise. If **sz** is larger than **fileName**
        currently is the new bytes will be set to 0, if **sz** is smaller the
        file is simply truncated.

        **Warning:** This function can fail if the file doesn't exist.

        **See also** **resize** ().
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qfile.html#size

        **[override virtual] qint64 QFile::size() const**

        Reimplements: **QFileDevice::size() const** .
        """
        ...

    @typing.overload
    def open(self, flags: QIODeviceBase.OpenModeFlag) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#open

        **[override virtual] bool QFile::open(QIODeviceBase::OpenMode mode )**

        Reimplements: **QIODevice::open** (QIODeviceBase::OpenMode mode).

        Opens the file using OpenMode **mode** , returning true if successful;
        otherwise false.

        The **mode** must be QIODevice::ReadOnly, QIODevice::WriteOnly, or
        QIODevice::ReadWrite. It may also have additional flags, such as
        QIODevice::Text and QIODevice::Unbuffered.

        **Note:** In **WriteOnly**  or **ReadWrite**  mode, if the relevant file
        does not already exist, this function will try to create a new file
        before opening it.

        **See also** **QIODevice::OpenMode**  and **setFileName** ().
        """
        ...

    @typing.overload
    def open(
        self,
        fd: int,
        ioFlags: QIODeviceBase.OpenModeFlag,
        handleFlags: QFileDevice.FileHandleFlag = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#open-1

        **bool QFile::open(FILE * fh , QIODeviceBase::OpenMode mode ,
        QFileDevice::FileHandleFlags handleFlags = DontCloseHandle)**

        This is an overloaded function.

        Opens the existing file handle **fh** in the given **mode**.
        **handleFlags** may be used to specify additional options. Returns
        `true` if successful; otherwise returns `false`.

        Example:

        #include <stdio.h>

            void printError(const char* msg)
            {
        **QFile**  file;
                file.open(stderr, **QIODevice** ::WriteOnly);
        file.write(msg, qstrlen(msg));        // write to stderr
        file.close();
            }

        When a **QFile**  is opened using this function, behaviour of **close**
        () is controlled by the AutoCloseHandle flag. If AutoCloseHandle is
        specified, and this function succeeds, then calling **close** () closes
        the adopted handle. Otherwise, **close** () does not actually close the
        file, but only flushes it.

        **Warning:**

        1. If **fh** does not refer to a regular file, e.g., it is `stdin`,
        `stdout`, or `stderr`, you may not be able to **seek** (). **size** ()
        returns `0` in those cases. See **QIODevice::isSequential** () for more
        information.
          2. Since this function opens the file without specifying
        the file name, you cannot use this **QFile**  with a **QFileInfo** .

        **Note for the Windows Platform**

        **fh** must be opened in binary mode (i.e., the mode string must contain
        'b', as in "rb" or "wb") when accessing files and other random-access
        devices. Qt will translate the end-of-line characters if you pass
        QIODevice::Text to **mode**. Sequential devices, such as stdin and
        stdout, are unaffected by this limitation.

        You need to enable support for console applications in order to use the
        stdin, stdout and stderr streams at the console. To do this, add the
        following declaration to your application's project file:

        CONFIG += console

        **See also** **close** ().
        """
        ...

    @typing.overload
    def copy(self, newName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#copy

        **bool QFile::copy(const QString & newName )**

        Copies the file named **fileName** () to **newName**.

        This file is closed before it is copied.

        If the copied file is a symbolic link (symlink), the file it refers to
        is copied, not the link itself. With the exception of permissions, which
        are copied, no other file metadata is copied.

        Returns `true` if successful; otherwise returns `false`.

        Note that if a file with the name **newName** already exists, copy()
        returns `false`. This means **QFile**  will not overwrite it.

        **See also** **setFileName** ().
        """
        ...

    @typing.overload
    @staticmethod
    def copy(fileName: str, newName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#copy-1

        **[since 6.0] bool QFile::copy(const std::filesystem::path & newName )**

        This is an overloaded function.

        This function was introduced in Qt 6.0.
        """
        ...

    @typing.overload
    def link(self, newName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#link

        **bool QFile::link(const QString & linkName )**

        Creates a link named **linkName** that points to the file currently
        specified by **fileName** (). What a link is depends on the underlying
        filesystem (be it a shortcut on Windows or a symbolic link on Unix).
        Returns `true` if successful; otherwise returns `false`.

        This function will not overwrite an already existing entity in the file
        system; in this case, `link()` will return false and set **error** () to
        return **RenameError** .

        **Note:** To create a valid link on Windows, **linkName** must have a
        `.lnk` file extension.

        **See also** **setFileName** ().
        """
        ...

    @typing.overload
    @staticmethod
    def link(oldname: str, newName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#link-1

        **[since 6.0] bool QFile::link(const std::filesystem::path & newName )**

        This is an overloaded function.

        This function was introduced in Qt 6.0.
        """
        ...

    @typing.overload
    def rename(self, newName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#rename

        **bool QFile::rename(const QString & newName )**

        Renames the file currently specified by **fileName** () to **newName**.
        Returns `true` if successful; otherwise returns `false`.

        If a file with the name **newName** already exists, rename() returns
        `false` (i.e., **QFile**  will not overwrite it).

        The file is closed before it is renamed.

        If the rename operation fails, Qt will attempt to copy this file's
        contents to **newName** , and then remove this file, keeping only
        **newName**. If that copy operation fails or this file can't be removed,
        the destination file **newName** is removed to restore the old state.

        **See also** **setFileName** ().
        """
        ...

    @typing.overload
    @staticmethod
    def rename(oldName: str, newName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#rename-1

        **[since 6.0] bool QFile::rename(const std::filesystem::path & newName
        )**

        This is an overloaded function.

        This function was introduced in Qt 6.0.
        """
        ...

    @typing.overload
    def remove(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#remove

        **bool QFile::remove()**

        Removes the file specified by **fileName** (). Returns `true` if
        successful; otherwise returns `false`.

        The file is closed before it is removed.

        **See also** **setFileName** ().
        """
        ...

    @typing.overload
    @staticmethod
    def remove(fileName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#remove-1

        **[static] bool QFile::remove(const QString & fileName )**

        This is an overloaded function.

        Removes the file specified by the **fileName** given.

        Returns `true` if successful; otherwise returns `false`.

        **See also** **remove** ().
        """
        ...

    @typing.overload
    def symLinkTarget(self) -> str:
        """
        https://doc.qt.io/qt-6/qfile.html#symLinkTarget

        **[static] QString QFile::symLinkTarget(const QString & fileName )**

        Returns the absolute path of the file or directory referred to by the
        symlink (or shortcut on Windows) specified by **fileName** , or returns
        an empty string if the **fileName** does not correspond to a symbolic
        link.

        This name may not represent an existing file; it is only a string.
        **QFile::exists** () returns `true` if the symlink points to an existing
        file.
        """
        ...

    @typing.overload
    @staticmethod
    def symLinkTarget(fileName: str) -> str:
        """
        https://doc.qt.io/qt-6/qfile.html#symLinkTarget-1

        **QString QFile::symLinkTarget() const**

        This is an overloaded function.

        Returns the absolute path of the file or directory a symlink (or
        shortcut on Windows) points to, or a an empty string if the object isn't
        a symbolic link.

        This name may not represent an existing file; it is only a string.
        **QFile::exists** () returns `true` if the symlink points to an existing
        file.

        **See also** **fileName** () and **setFileName** ().
        """
        ...

    @typing.overload
    def exists(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#exists

        **[static] bool QFile::exists(const QString & fileName )**

        Returns `true` if the file specified by **fileName** exists; otherwise
        returns `false`.

        **Note:** If **fileName** is a symlink that points to a non-existing
        file, false is returned.
        """
        ...

    @typing.overload
    @staticmethod
    def exists(fileName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfile.html#exists-1

        **bool QFile::exists() const**

        This is an overloaded function.

        Returns `true` if the file specified by **fileName** () exists;
        otherwise returns `false`.

        **See also** **fileName** () and **setFileName** ().
        """
        ...

    @typing.overload
    @staticmethod
    def decodeName(localFileName: QByteArray) -> str:
        """
        https://doc.qt.io/qt-6/qfile.html#decodeName

        **[static] QString QFile::decodeName(const QByteArray & localFileName
        )**

        This does the reverse of **QFile::encodeName** () using
        **localFileName**.

        **See also** **encodeName** ().
        """
        ...

    @typing.overload
    @staticmethod
    def decodeName(localFileName: str) -> str:
        """
        https://doc.qt.io/qt-6/qfile.html#decodeName-1

        **[static] QString QFile::decodeName(const char * localFileName )**

        This is an overloaded function.

        Returns the Unicode version of the given **localFileName**. See
        **encodeName** () for details.
        """
        ...

    @staticmethod
    def encodeName(fileName: str) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qfile.html#encodeName

        **[static] QByteArray QFile::encodeName(const QString & fileName )**

        Converts **fileName** to the local 8-bit encoding determined by the
        user's locale. This is sufficient for file names that the user chooses.
        File names hard-coded into the application should only use 7-bit ASCII
        filename characters.

        **See also** **decodeName** ().
        """
        ...

    def setFileName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qfile.html#setFileName

        **void QFile::setFileName(const QString & name )**

        Sets the **name** of the file. The name can have no path, a relative
        path, or an absolute path.

        Do not call this function if the file has already been opened.

        If the file name has no path or a relative path, the path used will be
        the application's current directory path **at the time of the**open**
        ()** call.

        Example:

        **QFile**  file;
            **QDir** ::setCurrent("/tmp");
        file.setFileName("readme.txt");
            **QDir** ::setCurrent("/home");
        file.open(**QIODevice** ::ReadOnly);      // opens "/home/readme.txt"
        under Unix

        Note that the directory separator "/" works for all operating systems
        supported by Qt.

        **See also** **fileName** (), **QFileInfo** , and **QDir** .
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qfile.html#fileName

        **[override virtual] QString QFile::fileName() const**

        Reimplements: **QFileDevice::fileName() const** .

        Returns the name set by **setFileName** () or to the **QFile**
        constructors.

        **See also** **setFileName** () and **QFileInfo::fileName** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QXmlStreamNamespaceDeclaration(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qxmlstreamnamespacedeclaration.html

    **Detailed Description**

    An namespace declaration consists of a **prefix** () and a **namespaceUri**
    ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamnamespacedeclaration.html#QXmlStreamNam
        espaceDeclaration

        **QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration()**

        Creates an empty namespace declaration.
        """
        ...

    @typing.overload
    def __init__(self, prefix: str, namespaceUri: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamnamespacedeclaration.html#QXmlStreamNam
        espaceDeclaration-1

        **QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration(const
        QString & prefix , const QString & namespaceUri )**

        Creates a namespace declaration with **prefix** and **namespaceUri**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QXmlStreamNamespaceDeclaration") -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamnamespacedeclaration.html#QXmlStreamNam
        espaceDeclaration

        **QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration()**

        Creates an empty namespace declaration.
        """
        ...

    def namespaceUri(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamnamespacedeclaration.html#namespaceUri

        **QStringView QXmlStreamNamespaceDeclaration::namespaceUri() const**

        Returns the namespaceUri.
        """
        ...

    def prefix(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamnamespacedeclaration.html#prefix

        **QStringView QXmlStreamNamespaceDeclaration::prefix() const**

        Returns the prefix.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QDoubleValidator(QValidator):
    """
    https://doc.qt.io/qt-6/qdoublevalidator.html

    **Detailed Description**

    QDoubleValidator provides an upper bound, a lower bound, and a limit on the
    number of digits after the decimal point. It does not provide a **fixup** ()
    function.

    You can set the acceptable range in one call with **setRange** (), or with
    **setBottom** () and **setTop** (). Set the number of decimal places with
    **setDecimals** (). The **validate** () function returns the validation
    state.

    QDoubleValidator uses its **locale** () to interpret the number. For
    example, in the German locale, "1,234" will be accepted as the fractional
    number 1.234. In Arabic locales, QDoubleValidator will accept Arabic digits.

    **Note:** The **QLocale::NumberOptions**  set on the **locale** () also
    affect the way the number is interpreted. For example, since
    **QLocale::RejectGroupSeparator**  is not set by default, the validator will
    accept group separators. It is thus recommended to use **QLocale::toDouble**
    () to obtain the numeric value.

    **See also** **QIntValidator** , **QRegularExpressionValidator** ,
    **QLocale::toDouble** (), and **Line Edits Example** .
    """

    class Notation(enum.Enum):
        StandardNotation: QDoubleValidator = ...
        ScientificNotation: QDoubleValidator = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdoublevalidator.html#QDoubleValidator

        **QDoubleValidator::QDoubleValidator(QObject * parent = nullptr)**

        Constructs a validator object with a **parent** object that accepts any
        double.
        """
        ...

    @typing.overload
    def __init__(
        self,
        bottom: float,
        top: float,
        decimals: int,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdoublevalidator.html#QDoubleValidator-1

        **QDoubleValidator::QDoubleValidator(double bottom , double top , int
        decimals , QObject * parent = nullptr)**

        Constructs a validator object with a **parent** object. This validator
        will accept doubles from **bottom** to **top** inclusive, with up to
        **decimals** digits after the decimal point.
        """
        ...

    def notation(self) -> "QDoubleValidator.Notation":
        """
        https://doc.qt.io/qt-6/qdoublevalidator.html#notation-prop

        **notation : Notation**

        This property holds the notation of how a string can describe a number

        By default, this property is set to **ScientificNotation** .

        **Access functions:**

        QDoubleValidator::Notation **notation** () const
        void **setNotation**
        (QDoubleValidator::Notation)

        **Notifier signal:**

        void **notationChanged** (QDoubleValidator::Notation **notation** )

        **See also** **Notation** .
        """
        ...

    def setNotation(self, a0: "QDoubleValidator.Notation") -> None:
        """
        https://doc.qt.io/qt-6/qdoublevalidator.html#notation-prop

        **notation : Notation**

        This property holds the notation of how a string can describe a number

        By default, this property is set to **ScientificNotation** .

        **Access functions:**

        QDoubleValidator::Notation **notation** () const
        void **setNotation**
        (QDoubleValidator::Notation)

        **Notifier signal:**

        void **notationChanged** (QDoubleValidator::Notation **notation** )

        **See also** **Notation** .
        """
        ...

    def decimals(self) -> int:
        """
        https://doc.qt.io/qt-6/qdoublevalidator.html#decimals-prop

        **decimals : int**

        This property holds the validator's maximum number of digits after the
        decimal point

        By default, this property contains a value of 1000.

        **Access functions:**

        int **decimals** () const
        void **setDecimals** (int)

        **Notifier signal:**

        void **decimalsChanged** (int **decimals** )

        **See also** **setRange** ().
        """
        ...

    def top(self) -> float:
        """
        https://doc.qt.io/qt-6/qdoublevalidator.html#top-prop

        **top : double**

        This property holds the validator's maximum acceptable value

        By default, this property contains a value of infinity.

        **Access functions:**

        double **top** () const
        void **setTop** (double)

        **Notifier signal:**

        void **topChanged** (double **top** )

        **See also** **setRange** ().

        **Member Function Documentation**
        """
        ...

    def bottom(self) -> float:
        """
        https://doc.qt.io/qt-6/qdoublevalidator.html#bottom-prop

        **bottom : double**

        This property holds the validator's minimum acceptable value

        By default, this property contains a value of -infinity.

        **Access functions:**

        double **bottom** () const
        void **setBottom** (double)

        **Notifier signal:**

        void **bottomChanged** (double **bottom** )

        **See also** **setRange** ().
        """
        ...

    def setDecimals(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qdoublevalidator.html#decimals-prop

        **decimals : int**

        This property holds the validator's maximum number of digits after the
        decimal point

        By default, this property contains a value of 1000.

        **Access functions:**

        int **decimals** () const
        void **setDecimals** (int)

        **Notifier signal:**

        void **decimalsChanged** (int **decimals** )

        **See also** **setRange** ().
        """
        ...

    def setTop(self, a0: float) -> None:
        """
        https://doc.qt.io/qt-6/qdoublevalidator.html#top-prop

        **top : double**

        This property holds the validator's maximum acceptable value

        By default, this property contains a value of infinity.

        **Access functions:**

        double **top** () const
        void **setTop** (double)

        **Notifier signal:**

        void **topChanged** (double **top** )

        **See also** **setRange** ().

        **Member Function Documentation**
        """
        ...

    def setBottom(self, a0: float) -> None:
        """
        https://doc.qt.io/qt-6/qdoublevalidator.html#bottom-prop

        **bottom : double**

        This property holds the validator's minimum acceptable value

        By default, this property contains a value of -infinity.

        **Access functions:**

        double **bottom** () const
        void **setBottom** (double)

        **Notifier signal:**

        void **bottomChanged** (double **bottom** )

        **See also** **setRange** ().
        """
        ...

    def setRange(self, bottom: float, top: float, decimals: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdoublevalidator.html#setRange

        **void QDoubleValidator::setRange(double minimum , double maximum , int
        decimals = 0)**

        Sets the validator to accept doubles from **minimum** to **maximum**
        inclusive, with at most **decimals** digits after the decimal point.
        """
        ...

    def validate(self, a0: str, a1: int) -> typing.Tuple[QValidator.State, str, int]:
        """
        https://doc.qt.io/qt-6/qdoublevalidator.html#validate

        **[override virtual] QValidator::State
        QDoubleValidator::validate(QString & input , int & pos ) const**

        Reimplements: **QValidator::validate(QString &input, int &pos) const** .

        Returns **Acceptable**  if the string **input** contains a double that
        is within the valid range and is in the correct format.

        Returns **Intermediate**  if **input** contains a double that is outside
        the range or is in the wrong format; e.g. is empty.

        Returns **Invalid**  if the **input** is not a double or with too many
        digits after the decimal point.

        Note: If the valid range consists of just positive doubles (e.g. 0.0 to
        100.0) and **input** is a negative double then **Invalid**  is returned.
        If **notation** () is set to **StandardNotation** , and the input
        contains more digits before the decimal point than a double in the valid
        range may have, **Invalid**  is returned. If **notation** () is
        **ScientificNotation** , and the input is not in the valid range,
        **Intermediate**  is returned. The value may yet become valid by
        changing the exponent.

        By default, the **pos** parameter is not used by this validator.
        """
        ...

    @property
    def bottomChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def decimalsChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def notationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def topChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QExposeEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qexposeevent.html

    **Detailed Description**

    Expose events are sent to windows when they move between the un-exposed and
    exposed states.

    An exposed window is potentially visible to the user. If the window is moved
    off screen, is made totally obscured by another window, is minimized, or
    similar, an expose event is sent to the window, and isExposed() might change
    to false.

    Expose events should not be used to paint. Handle **QPaintEvent**  instead.

    The event handler **QWindow::exposeEvent** () receives expose events.
    """

    def __init__(self, rgn: "QRegion") -> None:
        """
        https://doc.qt.io/qt-6/qexposeevent.html#QExposeEvent-2

        **QExposeEvent::QExposeEvent(const QRegion & exposeRegion )**

        Constructs an expose event for the given **exposeRegion** which must be
        in local coordinates.
        """
        ...

    def clone(self) -> "QExposeEvent":
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6.QtCore import *
import enum


class QEventLoop(QObject):
    """
    https://doc.qt.io/qt-6/qeventloop.html

    **Detailed Description**

    At any time, you can create a QEventLoop object and call **exec** () on it
    to start a local event loop. From within the event loop, calling **exit** ()
    will force **exec** () to return.

    **See also** **QAbstractEventDispatcher** .
    """

    class ProcessEventsFlag(enum.Flag):
        AllEvents: QEventLoop = ...
        ExcludeUserInputEvents: QEventLoop = ...
        ExcludeSocketNotifiers: QEventLoop = ...
        WaitForMoreEvents: QEventLoop = ...
        X11ExcludeTimers: QEventLoop = ...

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qeventloop.html#QEventLoop

        **QEventLoop::QEventLoop(QObject * parent = nullptr)**

        Constructs an event loop object with the given **parent**.
        """
        ...

    def event(self, event: QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qeventloop.html#event

        **[override virtual] bool QEventLoop::event(QEvent * event )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    def quit(self) -> None:
        """
        https://doc.qt.io/qt-6/qeventloop.html#quit

        **[slot] void QEventLoop::quit()**

        Tells the event loop to exit normally.

        Same as exit(0).

        **See also** **QCoreApplication::quit** () and **exit** ().
        """
        ...

    def wakeUp(self) -> None:
        """
        https://doc.qt.io/qt-6/qeventloop.html#wakeUp

        **void QEventLoop::wakeUp()**

        Wakes up the event loop.

        **See also** **QAbstractEventDispatcher::wakeUp** ().
        """
        ...

    def isRunning(self) -> bool:
        """
        https://doc.qt.io/qt-6/qeventloop.html#isRunning

        **bool QEventLoop::isRunning() const**

        Returns `true` if the event loop is running; otherwise returns false.
        The event loop is considered running from the time when **exec** () is
        called until **exit** () is called.

        **See also** **exec** () and **exit** ().
        """
        ...

    def exit(self, returnCode: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qeventloop.html#exit

        **[slot] void QEventLoop::exit(int returnCode = 0)**

        Tells the event loop to exit with a return code.

        After this function has been called, the event loop returns from the
        call to **exec** (). The **exec** () function returns **returnCode**.

        By convention, a **returnCode** of 0 means success, and any non-zero
        value indicates an error.

        Note that unlike the C library function of the same name, this function
        **does** return to the caller -- it is event processing that stops.

        **See also** **QCoreApplication::quit** (), **quit** (), and **exec**
        ().
        """
        ...

    def exec(self, flags: "QEventLoop.ProcessEventsFlag" = ...) -> int:
        """
        https://doc.qt.io/qt-6/qeventloop.html#exec

        **int QEventLoop::exec(QEventLoop::ProcessEventsFlags flags =
        AllEvents)**

        Enters the main event loop and waits until **exit** () is called.
        Returns the value that was passed to **exit** ().

        If **flags** are specified, only events of the types allowed by the
        **flags** will be processed.

        It is necessary to call this function to start event handling. The main
        event loop receives events from the window system and dispatches these
        to the application widgets.

        Generally speaking, no user interaction can take place before calling
        exec(). As a special case, modal widgets like **QMessageBox**  can be
        used before calling exec(), because modal widgets use their own local
        event loop.

        To make your application perform idle processing (i.e. executing a
        special function whenever there are no pending events), use a **QTimer**
        with 0 timeout. More sophisticated idle processing schemes can be
        achieved using **processEvents** ().

        **See also** **QCoreApplication::quit** (), **exit** (), and
        **processEvents** ().
        """
        ...

    @typing.overload
    def processEvents(self, flags: "QEventLoop.ProcessEventsFlag" = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qeventloop.html#processEvents

        **bool QEventLoop::processEvents(QEventLoop::ProcessEventsFlags flags =
        AllEvents)**

        Processes some pending events that match **flags**. Returns `true` if
        pending events were handled; otherwise returns `false`.

        This function is especially useful if you have a long running operation
        and want to show its progress without allowing user input; i.e. by using
        the **ExcludeUserInputEvents**  flag.

        This function is simply a wrapper for
        **QAbstractEventDispatcher::processEvents** (). See the documentation
        for that function for details.
        """
        ...

    @typing.overload
    def processEvents(
        self, flags: "QEventLoop.ProcessEventsFlag", maximumTime: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qeventloop.html#processEvents-1

        **void QEventLoop::processEvents(QEventLoop::ProcessEventsFlags flags ,
        int maxTime )**

        Process pending events that match **flags** for a maximum of **maxTime**
        milliseconds, or until there are no more events to process, whichever is
        shorter. This function is especially useful if you have a long running
        operation and want to show its progress without allowing user input,
        i.e. by using the **ExcludeUserInputEvents**  flag.

        **Notes:**

        * This function does not process events continuously; it returns after
        all available events are processed.
          * Specifying the
        **WaitForMoreEvents**  flag makes no sense and will be ignored.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QActionGroup(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qactiongroup.html

    **Detailed Description**

    QActionGroup is a base class for classes grouping classes inhheriting
    **QAction**  objects together.

    In some situations it is useful to group **QAction**  objects together. For
    example, if you have a **Left Align** action, a **Right Align** action, a
    **Justify** action, and a **Center** action, only one of these actions
    should be active at any one time. One simple way of achieving this is to
    group the actions together in an action group, inheriting QActionGroup.

    **See also** **QAction** .
    """

    class ExclusionPolicy(enum.Enum):
        None_: QActionGroup = ...
        Exclusive: QActionGroup = ...
        ExclusiveOptional: QActionGroup = ...

    def __init__(self, parent: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#QActionGroup

        **QActionGroup::QActionGroup(QObject * parent )**

        Constructs an action group for the **parent** object.

        The action group is exclusive by default. Call **setExclusive** (false)
        to make the action group non-exclusive. To make the group exclusive but
        allow unchecking the active action call instead **setExclusionPolicy**
        (**QActionGroup::ExclusionPolicy::ExclusiveOptional** )
        """
        ...

    def hovered(self, a0: QAction) -> None:
        ...

    def triggered(self, a0: QAction) -> None:
        ...

    def setExclusionPolicy(self, policy: "QActionGroup.ExclusionPolicy") -> None:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#exclusionPolicy-prop

        **exclusionPolicy : QActionGroup::ExclusionPolicy**

        This property holds the group exclusive checking policy

        If exclusionPolicy is set to Exclusive, only one checkable action in the
        action group can ever be active at any time. If the user chooses another
        checkable action in the group, the one they chose becomes active and the
        one that was active becomes inactive. If exclusionPolicy is set to
        ExclusionOptional the group is exclusive but the active checkable action
        in the group can be unchecked leaving the group with no actions checked.

        **Access functions:**

        QActionGroup::ExclusionPolicy **exclusionPolicy** () const
        void
        **setExclusionPolicy** (QActionGroup::ExclusionPolicy **policy** )

        **See also** **QAction::checkable** .
        """
        ...

    def setExclusive(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#setExclusive

        **[slot] void QActionGroup::setExclusive(bool b )**

        Enable or disable the group exclusion checking

        This is a convenience method that calls **setExclusionPolicy**
        (**ExclusionPolicy::Exclusive** ) when **b** is true, else
        **setExclusionPolicy** (**QActionGroup::ExclusionPolicy::None** ).

        **See also** **isExclusive** () and **QActionGroup::exclusionPolicy** .
        """
        ...

    def setVisible(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#visible-prop

        **visible : bool**

        This property holds whether the action group is visible

        Each action in the action group will match the visible state of this
        group unless it has been explicitly hidden.

        **Access functions:**

        bool **isVisible** () const
        void **setVisible** (bool)

        **See also** **QAction::setEnabled** ().

        **Member Function Documentation**
        """
        ...

    def setDisabled(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#setDisabled

        **[slot] void QActionGroup::setDisabled(bool b )**

        This is a convenience function for the **enabled**  property, that is
        useful for signals--slots connections. If **b** is true the action group
        is disabled; otherwise it is enabled.
        """
        ...

    def setEnabled(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#enabled-prop

        **enabled : bool**

        This property holds whether the action group is enabled

        Each action in the group will be enabled or disabled unless it has been
        explicitly disabled.

        **Access functions:**

        bool **isEnabled** () const
        void **setEnabled** (bool)

        **See also** **QAction::setEnabled** ().
        """
        ...

    def exclusionPolicy(self) -> "QActionGroup.ExclusionPolicy":
        """
        https://doc.qt.io/qt-6/qactiongroup.html#exclusionPolicy-prop

        **exclusionPolicy : QActionGroup::ExclusionPolicy**

        This property holds the group exclusive checking policy

        If exclusionPolicy is set to Exclusive, only one checkable action in the
        action group can ever be active at any time. If the user chooses another
        checkable action in the group, the one they chose becomes active and the
        one that was active becomes inactive. If exclusionPolicy is set to
        ExclusionOptional the group is exclusive but the active checkable action
        in the group can be unchecked leaving the group with no actions checked.

        **Access functions:**

        QActionGroup::ExclusionPolicy **exclusionPolicy** () const
        void
        **setExclusionPolicy** (QActionGroup::ExclusionPolicy **policy** )

        **See also** **QAction::checkable** .
        """
        ...

    def isVisible(self) -> bool:
        ...

    def isEnabled(self) -> bool:
        ...

    def isExclusive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#isExclusive

        **bool QActionGroup::isExclusive() const**

        Returns true if the group is exclusive

        The group is exclusive if the **ExclusionPolicy**  is either Exclusive
        or ExclusionOptional.
        """
        ...

    def checkedAction(self) -> QAction:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#checkedAction

        **QAction *QActionGroup::checkedAction() const**

        Returns the currently checked action in the group, or `nullptr` if none
        are checked.
        """
        ...

    def actions(self) -> typing.List[QAction]:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#actions

        **QList<QAction *> QActionGroup::actions() const**

        Returns the list of this groups's actions. This may be empty.
        """
        ...

    def removeAction(self, a: QAction) -> None:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#removeAction

        **void QActionGroup::removeAction(QAction * action )**

        Removes the **action** from this group. The action will have no parent
        as a result.

        **See also** **QAction::setActionGroup** ().
        """
        ...

    @typing.overload
    def addAction(self, a: QAction) -> QAction:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#addAction

        **QAction *QActionGroup::addAction(QAction * action )**

        Adds the **action** to this group, and returns it.

        Normally an action is added to a group by creating it with the group as
        its parent, so this function is not usually used.

        **See also** **QAction::setActionGroup** ().
        """
        ...

    @typing.overload
    def addAction(self, text: str) -> QAction:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#addAction-1

        **QAction *QActionGroup::addAction(const QString & text )**

        Creates and returns an action with **text**. The newly created action is
        a child of this action group.

        Normally an action is added to a group by creating it with the group as
        parent, so this function is not usually used.

        **See also** **QAction::setActionGroup** ().
        """
        ...

    @typing.overload
    def addAction(self, icon: "QIcon", text: str) -> QAction:
        """
        https://doc.qt.io/qt-6/qactiongroup.html#addAction-2

        **QAction *QActionGroup::addAction(const QIcon & icon , const QString &
        text )**

        Creates and returns an action with **text** and an **icon**. The newly
        created action is a child of this action group.

        Normally an action is added to a group by creating it with the group as
        its parent, so this function is not usually used.

        **See also** **QAction::setActionGroup** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6.QtQml import *


class QQmlIncubationController(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qqmlincubationcontroller.html

    **Detailed Description**

    In order to behave asynchronously and not introduce stutters or freezes in
    an application, the process of creating objects a QQmlIncubators must be
    driven only during the application's idle time. QQmlIncubationController
    allows the application to control exactly when, how often and for how long
    this processing occurs.

    A QQmlIncubationController derived instance should be created and set on a
    **QQmlEngine**  by calling the **QQmlEngine::setIncubationController** ()
    method. Processing is then controlled by calling the
    **QQmlIncubationController::incubateFor** () or
    **QQmlIncubationController::incubateWhile** () methods as dictated by the
    application's requirements.

    For example, this is an example of a incubation controller that will
    incubate for a maximum of 5 milliseconds out of every 16 milliseconds.

    class PeriodicIncubationController : public **QObject** ,
    public QQmlIncubationController
        {
        public:
    PeriodicIncubationController() {
                startTimer(16);
            }
    protected:
            void timerEvent(**QTimerEvent**  *) override {
    incubateFor(5);
            }
        };

    Although the previous example would work, it is not optimal. Real world
    incubation controllers should try and maximize the amount of idle time they
    consume - rather than a static amount like 5 milliseconds - while not
    disturbing the application.
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlincubationcontroller.html#QQmlIncubationContr
        oller-1

        **QQmlIncubationController::QQmlIncubationController()**

        Create a new incubation controller.
        """
        ...

    def incubatingObjectCountChanged(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qqmlincubationcontroller.html#incubatingObjectCou
        ntChanged

        **[virtual protected] void
        QQmlIncubationController::incubatingObjectCountChanged(int
        incubatingObjectCount )**

        Called when the number of incubating objects changes.
        **incubatingObjectCount** is the new number of incubating objects.

        The default implementation does nothing.
        """
        ...

    def incubateFor(self, msecs: int) -> None:
        """
        https://doc.qt.io/qt-6/qqmlincubationcontroller.html#incubateFor

        **void QQmlIncubationController::incubateFor(int msecs )**

        Incubate objects for **msecs** , or until there are no more objects to
        incubate.
        """
        ...

    def incubatingObjectCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qqmlincubationcontroller.html#incubatingObjectCou
        nt

        **int QQmlIncubationController::incubatingObjectCount() const**

        Return the number of objects currently incubating.
        """
        ...

    def engine(self) -> QQmlEngine:
        """
        https://doc.qt.io/qt-6/qqmlincubationcontroller.html#engine

        **QQmlEngine *QQmlIncubationController::engine() const**

        Return the **QQmlEngine**  this incubation controller is set on, or 0 if
        it has not been set on any engine.
        """
        ...
